# Databricks notebook source
"""
Application is the entry point to running the TPC-DI evaluation on databricks

The evaluation class is intended for interactive use. For timed benchmark runs
see benchmark.py
"""

from .warehouse.warehouse import Warehouse
from .staging.staging import Staging
from .transformation.historicalClass import HistoricalClass
from .preparationPhase import PreparationPhase
from .historicalLoadPhase import HistoricalLoadPhase
from .incrementalUpdatePhase import IncrementalUpdatePhase
from .validation.validation import Validation
from .auditPhase import AuditPhase
from pyspark.sql import SparkSession
from os.path import exists as path_exists

class Evaluation(PreparationPhase,
                 HistoricalLoadPhase,
                 IncrementalUpdatePhase,
                 AuditPhase):

    def __init__(self, sf=3, db_prefix='tpcdi',
                 stg_dir='dbfs:/user/hive/warehouse/{db_prefix}_stg_{sf}.db/pdgf_output',
                 pdgf_gen_dir_parent='/tmp/tpcdi_data_gen'):
        self.spark = SparkSession.builder.getOrCreate()
        self.sf = sf
        self.stg_name = f'{db_prefix}_stg_{sf}'
        self.wh_name = f'{db_prefix}_wh_{sf}'
        self.stg_dir = stg_dir.format(db_prefix=db_prefix, sf=sf)
        self.stg_dir_local = '/dbfs' + self.stg_dir[5:]
        self.pdgf_gen_dir_parent = f'{pdgf_gen_dir_parent}/{self.stg_name}'
        self.staging = Staging(self.stg_name, self.stg_dir)
        self.warehouse = Warehouse(self.wh_name)
        if path_exists(self.stg_dir_local + '/Batch1'):
            self._set_historical_incremental_validation()
