#! /usr/bin/env python

"""
The historical Load Phase Is composed of the following tasks:
Historical Load
the Validation Query

Historical Load Phase (Clause 7.2.4)
3. Incremental Update 1 Phase with an e



After all transformations specified in section 4.5 have been completed, the batch validation
query given in Clause 7.4 is executed. Upon completion of the batch validation query, a phase
completion record (PCR) is written to the DImessages table.

The Historical Load phase is timed as described in Clause 7.5.2
Write PCD

Calculating Throughput
"""

import sys
from .staging.staging import Staging
from .warehouse.warehouse import Warehouse
from .transformation.historicalClass import HistoricalClass
from .validation.validation import Validation
from .pcr.pcr import run_pcr
import datetime

class HistoricalLoadPhase:

    historical: HistoricalClass
    validation: Validation

    def run_historical_load_phase(self):
        start_time = datetime.datetime.now()
        self.historical.run_loads()
        self.validation.run_validation()
        phase_duration = round((datetime.datetime.now() - start_time).total_seconds() / 60.0, 2)
        run_pcr(1, self.historical.wh_name, phase_duration)
        print('Historic Load Phase Minutes Duration: ' + str(phase_duration))

def historical_load_main(sf=3):
    hlp = HistoricalLoadPhase()

    hlp.historical = HistoricalClass(Staging(f'tpcdi_stg_{sf}',
                                             f'dbfs:/user/hive/warehouse/tpcdi_stg_{sf}.db/pdgf_output'),
                                     Warehouse(f'tpcdi_wh_{sf}'))
    hlp.validation = Validation(Warehouse(f'tpcdi_wh_{sf}'))
    hlp.run_historical_load_phase()


if __name__ == "__main__":
    scale_factor = int(sys.argv[1])
    historical_load_main(scale_factor)
