#! /usr/bin/env python

"""
The incremental Load Phase Is composed of the following tasks:



Historical Load Phase (Clause 7.2.4)
3. Incremental Update 1 Phase with an e



After all transformations specified in section 4.5 have been completed, the batch validation
query given in Clause 7.4 is executed. Upon completion of the batch validation query, a phase
completion record (PCR) is written to the DImessages table.

The Historical Load phase is timed as described in Clause 7.5.2
Write PCD

Calculating Throughput
"""

import sys
from .staging.staging import Staging
from .warehouse.warehouse import Warehouse
from .transformation.incrementalClass import IncrementalClass
from .validation.validation import Validation
from .pcr.pcr import run_pcr

import datetime


class IncrementalUpdatePhase:

    wh_name: str
    incremental_1: IncrementalClass
    incremental_2: IncrementalClass
    validation: Validation

    def run_incremental_update_phase(self):
        start_time = datetime.datetime.now()
        self.incremental_1.run_updates()
        self.validation.run_validation()
        self.incremental_2.run_updates()
        self.validation.run_validation()
        phase_duration = round((datetime.datetime.now() - start_time).total_seconds() / 60.0, 2)
        run_pcr(1, self.wh_name, phase_duration)
        print('Incremental Update Phase Minutes Duration: ' + str(phase_duration))

def incremental_update_main(sf=3):
    iup = IncrementalUpdatePhase()
    iup.wh_name = f'tpcdi_wh_{sf}'
    iup.incremental_1 = IncrementalClass(Staging(f'tpcdi_stg_{sf}',
                                                 f'dbfs:/user/hive/warehouse/tpcdi_stg_{sf}.db/pdgf_output'),
                                         Warehouse(iup.wh_name), 2)
    iup.incremental_2 = IncrementalClass(Staging(f'tpcdi_stg_{sf}',
                                                 f'dbfs:/user/hive/warehouse/tpcdi_stg_{sf}.db/pdgf_output'),
                                         Warehouse(iup.wh_name), 3)
    iup.validation = Validation()
    iup.run_incremental_update_phase()


if __name__ == "__main__":
    scale_factor = int(sys.argv[1])
    incremental_update_main(scale_factor)
