"""
Phase Completion Record

The phase completion record is written at multiple times within TPCDI

 - End of Initialization Phase (7.2.3.5)
 - End of Historical Load Phase (7.2.4.2)
 - End of Incremental Update Phase (7.2.5.3)

"""

from pyspark.sql.session import SparkSession
from pyspark.sql.functions import current_timestamp, col, lit

def run_pcr(batch_id, wh_name, phase_duration=0):
    spark = SparkSession.builder.getOrCreate()
    message_source = ['Initialization',
                      'Historical Load',
                      'Incremental Update 1',
                      'Incremental Update 2',
                      'Audit'][batch_id]
    record = [(batch_id, message_source, 'PCR', 'Phase Completion Record')]
    cols = ['BatchID', 'MessageSource', 'MessageType', 'MessageText']
    spark.createDataFrame(record, cols) \
         .select(current_timestamp().alias('MessageDateAndTime'),
                 col('BatchID'),
                 col('MessageSource'),
                 col('MessageText'),
                 col('MessageType'),
                 lit(phase_duration).alias('MessageData')) \
        .write.insertInto(wh_name + '.DImessages')
