"""
Functions for Staging CustomerMgmt.xml Files

definition is taken exactly from table 

TPC-DI Requirement: 2.2.2.5
TPC-DI Ref: http://tpc.org/tpc_documents_current_versions/pdf/tpc-di_v1.1.0.pdf#page=23
"""

from ..stgData import StgData
from ..fileFormatDef import *
from pyspark.sql.types import StructType, StructField, StringType

PhoneNumber = StructType([StructField("C_AREA_CODE", CHAR(3),   True),
                          StructField("C_CTRY_CODE", CHAR(3),   True),
                          StructField("C_EXT",       CHAR(10),  True),
                          StructField("C_LOCAL",     CHAR(5),   True)])

Customer = StructType([
                StructField("_C_ID",              IDENT_T,      True),
                StructField("_C_TAX_ID",          CHAR(20),     True),
                StructField("_C_GNDR",            CHAR(1),      True),
                StructField("_C_TIER",            NUM(1),       True),
                StructField("_C_DOB",             DATE,         True),
                StructField("Name", StructType([
                    StructField("C_L_NAME",       CHAR(25),     True),
                    StructField("C_F_NAME",       CHAR(20),     True),
                    StructField("C_M_NAME",       CHAR(1),      True)]), True),
	            StructField("Address", StructType([
                    StructField("C_ADLINE1",      CHAR(80),     True),
                    StructField("C_ADLINE2",      CHAR(80),     True),
                    StructField("C_ZIPCODE",      CHAR(12),     True),
                    StructField("C_CITY",         CHAR(25),     True),
                    StructField("C_STATE_PROV",   CHAR(20),     True),
                    StructField("C_CTRY",         CHAR(24),     True)]), True),
	            StructField("ContactInfo", StructType([
                    StructField("C_PRIM_EMAIL",   CHAR(50),     True),
                    StructField("C_ALT_EMAIL",    CHAR(50),     True),
                    StructField("C_PHONE_1",      PhoneNumber,  True),
                    StructField("C_PHONE_2",      PhoneNumber,  True),
                    StructField("C_PHONE_3",      PhoneNumber,  True)]), True),
                StructField("TaxInfo", StructType([
                    StructField("C_LCL_TX_ID",    CHAR(4),      True),
                    StructField("C_NAT_TX_ID",    CHAR(4),      True)]), True),
	            StructField("Account",StructType([
                    StructField("_CA_ID",         IDENT_T,      True),
                    StructField("_CA_TAX_ST",     NUM(1),       True),
                    StructField("CA_B_ID",        IDENT_T,      True),
                    StructField("CA_NAME",        CHAR(50),     True)]), True)])


class CustomerMgmt(StgData):

    file_name = 'CustomerMgmt.xml'
    batches = [1, ]
    definition = [("_ActionType", CHAR(20), True, 'One of: NEW, ADDACCT, UPDACCT, UPDCUST,CLOSEACCT,INACT'),
                  ("_ActionTS",   CHAR(9),  True, "Date and time of action as YYYY-MM-DDTHH:MM:SS . ‘T’ is a literal value."),
                  ("Customer",    Customer, True, "Customer & Account Details")]

    def get_df(self, batch_id):
        if batch_id in self.batches:
            return self.spark.read.format("com.databricks.spark.xml") \
                             .schema(self.get_schema()) \
                             .option("rowTag", "TPCDI:Action") \
                             .option("treatEmptyValuesAsNulls", "true") \
                             .load(f'{self.stg_dir}/Batch{batch_id}/{self.file_name}')
        else:
            return None
