"""
Functions for Staging Date.txt Files

definition is taken exactly from table 2.2.11

TPC-DI Requirement: 2.2.2.7
TPC-DI Ref: http://tpc.org/tpc_documents_current_versions/pdf/tpc-di_v1.1.0.pdf#page=29
"""


from ..stgData import StgData
from ..fileFormatDef import *

class Date(StgData):

    file_name = 'Date.txt'
    batches = [1, ]
    definition = [("SK_DateID",         IDENT_T,  False, 'Surrogate key for the date'),
                  ("DateValue",         CHAR(20), False, 'The date as text, e.g. “2004-07-07”'),
                  ("DateDesc",          CHAR(20), False, 'The date Month Day, YYYY, e.g. July 7, 2004'),
                  ("CalendarYearID",    NUM(4),   False, 'Year number as a number'),
                  ("CalendarYearDesc",  CHAR(20), False, 'Year number as text'),
                  ("CalendarQtrID",     NUM(5),   False, 'Quarter as a number, e.g. 20042'),
                  ("CalendarQtrDesc",   CHAR(20), False, 'Quarter as text, e.g. “2004 Q2”'),
                  ("CalendarMonthID",   NUM(6),   False, 'Month as a number, e.g. 20047'),
                  ("CalendarMonthDesc", CHAR(20), False, 'Month as text, e.g. “2004 July”'),
                  ("CalendarWeekID",    NUM(6),   False, 'Week as a number, e.g. 200428'),
                  ("CalendarWeekDesc",  CHAR(20), False, 'Week as text, e.g. “2004-W28”'),
                  ("DayOfWeekNum",      NUM(1),   False, 'Day of week as a number, e.g. 3'),
                  ("DayOfWeekDesc",     CHAR(10), False, 'Day of week as text, e.g. “Wednesday”'),
                  ("FiscalYearID",      NUM(4),   False, 'Fiscal year as a number, e.g. 2005'),
                  ("FiscalYearDesc",    CHAR(20), False, 'Fiscal year as text, e.g. “2005”'),
                  ("FiscalQtrID",       NUM(5),   False, 'Fiscal quarter as a number, e.g. 20051'),
                  ("FiscalQtrDesc",     CHAR(20), False, 'Fiscal quarter as text, e.g. “2005 Q1”'),
                  ("HolidayFlag",       BOOLEAN,  False, 'Indicated holidays')]
          