"""
Functions for Staging Prospect.csv Files

definition is taken exactly from table 2.2.12

TPC-DI Requirement: 2.2.2.12
TPC-DI Ref: http://tpc.org/tpc_documents_current_versions/pdf/tpc-di_v1.1.0.pdf#page=32
"""


from ..stgData import StgData
from ..fileFormatDef import *

class RawProspect(StgData):

    file_name = 'Prospect.csv'
    definition = [("AgencyID",          CHAR(30), False, "Not NULL Unique identifier from agency"),
                  ("LastName",          CHAR(30), False, "Not NULL Last name"),
                  ("FirstName",         CHAR(30), False, "Not NULL First name"),
                  ("MiddleInitial",     CHAR(1),  True,  "Middle initial"),
                  ("Gender",            CHAR(1),  True,  "‘M’ or ‘F’ or ‘U’"),
                  ("AddressLine1",      CHAR(80), True,  "Postal address"),
                  ("AddressLine2",      CHAR(80), True,  "Postal address"),
                  ("PostalCode",        CHAR(12), True,  "Postal code"),
                  ("City",              CHAR(25), False, "Not NULL City"),
                  ("State",             CHAR(20), False, "Not NULL State or province"),
                  ("Country",           CHAR(24), True,  "Postal country"),
                  ("Phone",             CHAR(30), True,  "Telephone number"),
                  ("Income",            NUM(9),   True,  "Annual income"),
                  ("NumberCars",        NUM(2),   True,  "Cars owned"),
                  ("NumberChildren",    NUM(2),   True,  "Dependent children"),
                  ("MaritalStatus",     CHAR(1),  True,  "‘S’ or ‘M’ or ‘D’ or ‘W’ or ‘U’"),
                  ("Age",               NUM(3),   True,  "Current age"),
                  ("CreditRating",      NUM(4),   True,  "Numeric rating"),
                  ("OwnOrRentFlag",     CHAR(1),  True,  "‘O’ or ‘R’ or ‘U’"),
                  ("Employer",          CHAR(30), True,  "Name of employer"),
                  ("NumberCreditCards", NUM(2),   True,  "Credit cards"),
                  ("NetWorth",          NUM(12),  True,  "Estimated total net worth")]
