"""
Functions for Staging Trade.txt Files

definition is taken exactly from table 2.2.17

TPC-DI Requirement: 2.2.2.17
TPC-DI Ref: http://tpc.org/tpc_documents_current_versions/pdf/tpc-di_v1.1.0.pdf#page=34

NOTE: T_IS_CASH is BOOLEAN IN Docs, using byte because written as 1/0
"""


from ..stgData import StgData
from ..fileFormatDef import *
from pyspark.sql.types import ByteType
from pyspark.sql.functions import lit

class Trade(StgData):

    file_name = 'Trade.txt'
    definition = [("CDC_FLAG",      CDC_FLAG_T, True,  "‘I’, ‘U’ Denotes insert, update"),
                  ("CDC_DSN",       CDC_DSN_T,  True,  "Database Sequence Number"),
                  ("T_ID",          TRADE_T,    False, "Trade identifier."),
                  ("T_DTS",         DATETIME,   False, "Date and time of trade."),
                  ("T_ST_ID",       CHAR(4),    False, "Status type identifier"),
                  ("T_TT_ID",       CHAR(3),    False, "Trade type identifier"),
                  ("T_IS_CASH",     CHAR(1),    False, "‘0’ or ’1’ Is this trade a cash (‘1’) or margin (‘0’) trade ?"),
                  ("T_S_SYMB",      CHAR(15),   False, "Security symbol of the security"),
                  ("T_QTY",         S_QTY_T,    False, "Quantity of securities traded."),
                  ("T_BID_PRICE",   S_PRICE_T,  False, "The requested unit price."),
                  ("T_CA_ID",       IDENT_T,    False, "Customer account identifier."),
                  ("T_EXEC_NAME",   CHAR(49),   False, "Name of the person executing the trade."),
                  ("T_TRADE_PRICE", S_PRICE_T,  True,  "Unit price at which the security was traded."),
                  ("T_CHRG",        VALUE_T,    True,  "Fee charged for placing this trade request."),
                  ("T_COMM",        VALUE_T,    True,  "Commission earned on this trade"),
                  ("T_TAX",         VALUE_T,    True,  "Amount of tax due on this trade")]
