"""
File Format Definitions

Derived from definitions in 2.2, Table 2.2.1 & Table 2.2.2
http://tpc.org/tpc_documents_current_versions/pdf/tpc-di_v1.1.0.pdf#page=20

NOTE: In future Databricks Runtime, will be able to use DayTimeIntervalType for TIME

NOTE: There is no VarcharType in pyspark.sql.types. Thus instead of passing a varchar class we
      pass a string which is resolved in the delta table addColumn method.

From TPC-DI documentation:
Rationale: The input data all comes from text files, and in that context all values are character sequences.
These are not “native data types” in the sense that a database has native data types that it can store, but are
abstractions that describe the character sequences. These types do however correlate to the data types used in
section 3.2 to define the Data Warehouse tables
"""

from pyspark.sql.types import BooleanType, \
                              DateType, \
                              TimestampType, \
                              DecimalType, \
                              StringType


# Base Types:

BOOLEAN=BooleanType()

def CHAR(n):
    return StringType()

DATE=DateType()

DATETIME=TimestampType()

def NUM(m,n=0):
    return DecimalType(m,n)

def SNUM(m,n=0):
    return DecimalType(m,n)


# Meta Types:

BALANCE_T = SNUM(12,2)

CDC_FLAG_T = CHAR(1)

CDC_DSN_T = NUM(12)

IDENT_T = NUM(11)

S_COUNT_T = NUM(12)

S_PRICE_T = SNUM(8,2)

S_QTY_T = NUM(6)

TRADE_T = NUM(15)

VALUE_T = SNUM(10,2)

