"""
Staging contains all Staging requirements for Clause 2: Source Data Files

http://tpc.org/tpc_documents_current_versions/pdf/tpc-di_v1.1.0.pdf#page=20
"""

from .gvStaging import get_stg_html
from .data import STG_DATA
from pyspark.sql import SparkSession
import threading


class Staging:

    def __init__(self, stg_name, stg_dir):
        self.spark = SparkSession.builder.getOrCreate()
        self.name = stg_name
        self.dir = stg_dir
        self.Data = {d.__name__: d(self.spark, self.name, self.dir) for d in STG_DATA}

    def get_dataframes(self, batch_id):
        dataframes = {k: v.get_df(batch_id) for k, v in self.Data.items()}
        return {k: v for k, v in dataframes.items() if v is not None}

    def create(self):
        self.spark.sql(f'CREATE DATABASE IF NOT EXISTS {self.name}')

    def drop(self):
        self.spark.sql(f'DROP DATABASE IF EXISTS {self.name}')

    def create_tables(self):
        # for t in self.Data.values():
        #     t.create_tbl()
        table_threader = [threading.Thread(target=tc.create_table) for tc in self.Data.values()]
        for t in table_threader:
            t.start()
        for t in table_threader:
            t.join()

    def drop_tables(self):
        # for t in self.Data.values():
        #     t.drop_tbl()
        table_threader = [threading.Thread(target=tc.drop_table) for tc in self.Data.values()]
        for t in table_threader:
            t.start()
        for t in table_threader:
            t.join()

    def ingest(self):
        # for t in self.Data.values():
        #     t.ingest()
        table_threader = [threading.Thread(target=tc.ingest) for tc in self.Data.values()]
        for t in table_threader:
            t.start()
        for t in table_threader:
            t.join()

    def get_tables(self):
        return {k: v.get_table() for k, v in self.Data.items()}

    def create_views(self):
        # for t in self.Data.values():
        #     t.create_view()
        table_threader = [threading.Thread(target=tc.create_view) for tc in self.Data.values()]
        for t in table_threader:
            t.start()
        for t in table_threader:
            t.join()

    def get_html(self):
        return get_stg_html(self.name)
