"""
Collection of reusable transformation functions.
"""

from pyspark.sql.functions import concat, lit, when, concat_ws, col

def phoner(c_phone):
    ctry_code = col(c_phone + '.C_CTRY_CODE')
    area_code = col(c_phone + '.C_AREA_CODE')
    local = col(c_phone + '.C_LOCAL')
    ext = col(c_phone + '.C_EXT')
    ext = when(ext.isNull(), '').otherwise(ext)
    ph1 = concat(lit('+'), ctry_code, lit(' ('), area_code, lit(') '), local, lit(' '), ext)
    ph2 = concat(lit('('), area_code, lit(') '), local, lit(' '), ext)
    ph3 = concat(local, lit(' '), ext)
    return when(ph1.isNotNull(), ph1).otherwise(when(ph2.isNotNull(), ph2).otherwise(when(ph3.isNotNull(), ph3)))

def marketingnameplater():
    return concat_ws('+',
                     when((col('NetWorth') > lit(1000000)) | (col('Income') > lit(200000)), 'HighValue'),
                     when((col('NumberChildren') > lit(3)) | (col('NumberCreditCards') > lit(5)), 'Expenses'),
                     when(col('Age') > lit(45), "Boomer"),
                     when((col('Income') < lit(50000)) |
                          (col('CreditRating') < lit(600)) |
                          (col('NetWorth') < '10000'), "MoneyAlert"),
                     when((col('NumberCars') > lit(3)) | (col('NumberCreditCards') > lit(7)), "Spender"),
                     when((col('Age') < lit(25)) & (col('NetWorth') > lit(1000000)), "Inherited")) \
        .alias("MarketingNameplate")
