"""
Data Dependencies

The TPC-DI requirements explicitly stated data dependencies in 4.3.3. Opposed to deriving our own, we will make
reference to the explicit dependencies specified in documentation.

http://tpc.org/tpc_documents_current_versions/pdf/tpc-di_v1.1.0.pdf#page=53
"""


def get_trans_dependency_html(wh_name):
    import re    
    from graphviz import Digraph    

    dot = Digraph('tpcdi')
    dot.graph_attr['rankdir'] = 'LR'  
    dot.attr('node', shape='rectangle')    

    with dot.subgraph(name='cluster_DimAccount') as c:
        c.body.append('label="DimAccount"')
        c.body.append('color="blue"')
        c.node('dimaccount_sk_brokerid','SK_BrokerID')
        c.node('dimaccount_sk_customerid','SK_CustomerID')
        c.node('dimaccount_sk_accountid','SK_AccountID')    

    with dot.subgraph(name='cluster_DimBroker') as c:
        c.body.append('label="DimBroker"')
        c.body.append('color="blue"')
        c.node('dimbroker_sk_brokerid','SK_BrokerID')    

    with dot.subgraph(name='cluster_DimCompany') as c:
        c.body.append('label="DimCompany"')
        c.body.append('color="blue"')
        c.node('dimcompany_sk_companyid','SK_CompanyID')        

    with dot.subgraph(name='cluster_DimCustomer') as c:
        c.body.append('label="DimCustomer"')
        c.body.append('color="blue"')
        c.node('dimcustomer_sk_customerid','SK_CustomerID')        
        
    with dot.subgraph(name='cluster_DimDate') as c:
        c.body.append('label="DimDate"')
        c.body.append('color="blue"')
        c.node('dimdate_sk_dateid','SK_DateID')    
        
    with dot.subgraph(name='cluster_DimSecurity') as c:
        c.body.append('label="DimSecurity"')
        c.body.append('color="blue"')
        c.node('dimsecurity_sk_companyid','SK_CompanyID')            
        c.node('dimsecurity_sk_securityid','SK_SecurityID')    
            
    with dot.subgraph(name='cluster_DimTrade') as c:
        c.body.append('label="DimTrade"')
        c.body.append('color="blue"')
        c.node('dimtrade_sk_accountid','SK_AccountID')            
        c.node('dimtrade_sk_brokerid','SK_BrokerID')             
        c.node('dimtrade_sk_closedateid','SK_CloseDateID')          
        c.node('dimtrade_sk_closetimeid','SK_CloseTimeID')          
        c.node('dimtrade_sk_companyid','SK_CompanyID')            
        c.node('dimtrade_sk_createdateid','SK_CreateDateID')         
        c.node('dimtrade_sk_createtimeid','SK_CreateTimeID')         
        c.node('dimtrade_sk_customerid','SK_CustomerID')           
        c.node('dimtrade_sk_securityid','SK_SecurityID')           
        c.node('dimtrade_sk_currenttradeid','SK_CurrentTradeID')
        c.node('dimtrade_sk_tradeid','SK_TradeID')    
        
    with dot.subgraph(name='cluster_FactCashBalances') as c:
        c.body.append('label="FactCashBalances"')
        c.body.append('color="blue"')
        c.node('factcashbalances_sk_accountid','SK_AccountID')            
        c.node('factcashbalances_sk_customerid','SK_CustomerID')           
        c.node('factcashbalances_sk_dateid','SK_DateID')               
        c.node('factcashbalances_sk_timeid','SK_TimeID')        

    with dot.subgraph(name='cluster_FactHoldings') as c:
        c.body.append('label="FactHoldings"')
        c.body.append('color="blue"')
        c.node('factholdings_sk_accountid','SK_AccountID')            
        c.node('factholdings_sk_companyid','SK_CompanyID')            
        c.node('factholdings_sk_currenttradeid','SK_CurrentTradeID')       
        c.node('factholdings_sk_customerid','SK_CustomerID')           
        c.node('factholdings_sk_dateid','SK_DateID')               
        c.node('factholdings_sk_securityid','SK_SecurityID')           
        c.node('factholdings_sk_timeid','SK_TimeID')               
        c.node('factholdings_sk_tradeid','SK_TradeID')     
        
    with dot.subgraph(name='cluster_FactMarketHistory') as c:
        c.body.append('label="FactMarketHistory"')
        c.body.append('color="blue"')
        c.node('factmarkethistory_sk_companyid','SK_CompanyID')            
        c.node('factmarkethistory_sk_dateid','SK_DateID')               
        c.node('factmarkethistory_sk_securityid','SK_SecurityID')
            
    with dot.subgraph(name='cluster_FactWatches') as c:
        c.body.append('label="FactWatches"')
        c.body.append('color="blue"')
        c.node('factwatches_sk_customerid','SK_CustomerID')           
        c.node('factwatches_sk_dateid_dateplaced','SK_DateID_DatePlaced')    
        c.node('factwatches_sk_dateid_dateremoved','SK_DateID_DateRemoved')   
        c.node('factwatches_sk_securityid','SK_SecurityID')  
        
    with dot.subgraph(name='cluster_Prospect') as c:
        c.body.append('label="Prospect"')
        c.body.append('color="blue"')
        c.node('prospect_sk_updatedateid','SK_UpdateDateID') 
        
    with dot.subgraph(name='cluster_DimTime') as c:
        c.body.append('label="DimTime"')
        c.body.append('color="blue"')
        c.node('dimtime_sk_timeid','SK_TimeID')  
        
    dot.edge('dimbroker_sk_brokerid','dimaccount_sk_brokerid')
    dot.edge('dimcustomer_sk_customerid','dimaccount_sk_customerid')
    dot.edge('dimcompany_sk_companyid','dimsecurity_sk_companyid')
    dot.edge('dimbroker_sk_brokerid','dimtrade_sk_brokerid')
    dot.edge('dimdate_sk_dateid','dimtrade_sk_createdateid')
    dot.edge('dimtime_sk_timeid','dimtrade_sk_createtimeid')
    dot.edge('dimdate_sk_dateid','dimtrade_sk_closedateid')
    dot.edge('dimtime_sk_timeid','dimtrade_sk_closetimeid')
    dot.edge('dimsecurity_sk_securityid','dimtrade_sk_securityid')
    dot.edge('dimcompany_sk_companyid','dimtrade_sk_companyid')
    dot.edge('dimcustomer_sk_customerid','dimtrade_sk_customerid')
    dot.edge('dimaccount_sk_accountid','dimtrade_sk_accountid')
    dot.edge('dimcustomer_sk_customerid','factcashbalances_sk_customerid')
    dot.edge('dimaccount_sk_accountid','factcashbalances_sk_accountid')
    dot.edge('dimdate_sk_dateid','factcashbalances_sk_dateid')
    dot.edge('dimtime_sk_timeid','factcashbalances_sk_timeid')
    dot.edge('dimtrade_sk_tradeid','factholdings_sk_tradeid')
    dot.edge('dimtrade_sk_currenttradeid','factholdings_sk_currenttradeid')
    dot.edge('dimcustomer_sk_customerid','factholdings_sk_customerid')
    dot.edge('dimaccount_sk_accountid','factholdings_sk_accountid')
    dot.edge('dimsecurity_sk_securityid','factholdings_sk_securityid')
    dot.edge('dimcompany_sk_companyid','factholdings_sk_companyid')
    dot.edge('dimdate_sk_dateid','factholdings_sk_dateid')
    dot.edge('dimtime_sk_timeid','factholdings_sk_timeid')
    dot.edge('dimsecurity_sk_securityid','factmarkethistory_sk_securityid')
    dot.edge('dimcompany_sk_companyid','factmarkethistory_sk_companyid')
    dot.edge('dimdate_sk_dateid','factmarkethistory_sk_dateid')
    dot.edge('dimcustomer_sk_customerid','factwatches_sk_customerid')
    dot.edge('dimsecurity_sk_securityid','factwatches_sk_securityid')
    dot.edge('dimdate_sk_dateid','factwatches_sk_dateid_dateplaced')
    dot.edge('dimdate_sk_dateid','factwatches_sk_dateid_dateremoved')
    dot.edge('dimdate_sk_dateid','prospect_sk_updatedateid')    

    html = dot._repr_image_svg_xml()    

    return html

TC_DEP = [{'Dependent': {'Table': 'DimAccount', 'Column': 'SK_BrokerID'},
           'Source': {'Table': 'DimBroker', 'Column': 'SK_BrokerID'}},
          {'Dependent': {'Table': 'DimAccount', 'Column': 'SK_CustomerID'},
           'Source': {'Table': 'DimCustomer', 'Column': 'SK_CustomerID'}},
          {'Dependent': {'Table': 'DimSecurity', 'Column': 'SK_CompanyID'},
           'Source': {'Table': 'DimCompany', 'Column': 'SK_CompanyID'}},
          {'Dependent': {'Table': 'DimTrade', 'Column': 'SK_BrokerID'},
           'Source': {'Table': 'DimBroker', 'Column': 'SK_BrokerID'}},
          {'Dependent': {'Table': 'DimTrade', 'Column': 'SK_CreateDateID'},
           'Source': {'Table': 'DimDate', 'Column': 'SK_DateID'}},
          {'Dependent': {'Table': 'DimTrade', 'Column': 'SK_CreateTimeID'},
           'Source': {'Table': 'DimTime', 'Column': 'SK_TimeID'}},
          {'Dependent': {'Table': 'DimTrade', 'Column': 'SK_CloseDateID'},
           'Source': {'Table': 'DimDate', 'Column': 'SK_DateID'}},
          {'Dependent': {'Table': 'DimTrade', 'Column': 'SK_CloseTimeID'},
           'Source': {'Table': 'DimTime', 'Column': 'SK_TimeID'}},
          {'Dependent': {'Table': 'DimTrade', 'Column': 'SK_SecurityID'},
           'Source': {'Table': 'DimSecurity', 'Column': 'SK_SecurityID'}},
          {'Dependent': {'Table': 'DimTrade', 'Column': 'SK_CompanyID'},
           'Source': {'Table': 'DimCompany', 'Column': 'SK_CompanyID'}},
          {'Dependent': {'Table': 'DimTrade', 'Column': 'SK_CustomerID'},
           'Source': {'Table': 'DimCustomer', 'Column': 'SK_CustomerID'}},
          {'Dependent': {'Table': 'DimTrade', 'Column': 'SK_AccountID'},
           'Source': {'Table': 'DimAccount', 'Column': 'SK_AccountID'}},
          {'Dependent': {'Table': 'FactCashBalances', 'Column': 'SK_CustomerID'},
           'Source': {'Table': 'DimCustomer', 'Column': 'SK_CustomerID'}},
          {'Dependent': {'Table': 'FactCashBalances', 'Column': 'SK_AccountID'},
           'Source': {'Table': 'DimAccount', 'Column': 'SK_AccountID'}},
          {'Dependent': {'Table': 'FactCashBalances', 'Column': 'SK_DateID'},
           'Source': {'Table': 'DimDate', 'Column': 'SK_DateID'}},
          {'Dependent': {'Table': 'FactCashBalances', 'Column': 'SK_TimeID'},
           'Source': {'Table': 'DimTime', 'Column': 'SK_TimeID'}},
          {'Dependent': {'Table': 'FactHoldings', 'Column': 'SK_TradeID'},
           'Source': {'Table': 'DimTrade', 'Column': 'SK_TradeID'}},
          {'Dependent': {'Table': 'FactHoldings', 'Column': 'SK_CurrentTradeID'},
           'Source': {'Table': 'DimTrade', 'Column': 'SK_CurrentTradeID'}},
          {'Dependent': {'Table': 'FactHoldings', 'Column': 'SK_CustomerID'},
           'Source': {'Table': 'DimCustomer', 'Column': 'SK_CustomerID'}},
          {'Dependent': {'Table': 'FactHoldings', 'Column': 'SK_AccountID'},
           'Source': {'Table': 'DimAccount', 'Column': 'SK_AccountID'}},
          {'Dependent': {'Table': 'FactHoldings', 'Column': 'SK_SecurityID'},
           'Source': {'Table': 'DimSecurity', 'Column': 'SK_SecurityID'}},
          {'Dependent': {'Table': 'FactHoldings', 'Column': 'SK_CompanyID'},
           'Source': {'Table': 'DimCompany', 'Column': 'SK_CompanyID'}},
          {'Dependent': {'Table': 'FactHoldings', 'Column': 'SK_DateID'},
           'Source': {'Table': 'DimDate', 'Column': 'SK_DateID'}},
          {'Dependent': {'Table': 'FactHoldings', 'Column': 'SK_TimeID'},
           'Source': {'Table': 'DimTime', 'Column': 'SK_TimeID'}},
          {'Dependent': {'Table': 'FactMarketHistory', 'Column': 'SK_SecurityID'},
           'Source': {'Table': 'DimSecurity', 'Column': 'SK_SecurityID'}},
          {'Dependent': {'Table': 'FactMarketHistory', 'Column': 'SK_CompanyID'},
           'Source': {'Table': 'DimCompany', 'Column': 'SK_CompanyID'}},
          {'Dependent': {'Table': 'FactMarketHistory', 'Column': 'SK_DateID'},
           'Source': {'Table': 'DimDate', 'Column': 'SK_DateID'}},
          {'Dependent': {'Table': 'FactWatches', 'Column': 'SK_CustomerID'},
           'Source': {'Table': 'DimCustomer', 'Column': 'SK_CustomerID'}},
          {'Dependent': {'Table': 'FactWatches', 'Column': 'SK_SecurityID'},
           'Source': {'Table': 'DimSecurity', 'Column': 'SK_SecurityID'}},
          {'Dependent': {'Table': 'FactWatches', 'Column': 'SK_DateID_DatePlaced'},
           'Source': {'Table': 'DimDate', 'Column': 'SK_DateID'}},
          {'Dependent': {'Table': 'FactWatches', 'Column': 'SK_DateID_DateRemoved'},
           'Source': {'Table': 'DimDate', 'Column': 'SK_DateID'}},
          {'Dependent': {'Table': 'Prospect', 'Column': 'SK_UpdateDateID'},
           'Source': {'Table': 'DimDate', 'Column': 'SK_DateID'}}]