"""
Historical Loads

Graphic is intended to show the sequence of loads and source for Clause 4 Transformations

http://tpc.org/tpc_documents_current_versions/pdf/tpc-di_v1.1.0.pdf#page=52
"""

def get_historical_html():
    import re
    from graphviz import Graph

    dot = Graph('tpcdi')
    dot.graph_attr['rankdir'] = 'LR'
    dot.attr('node', shape='rectangle')

    def pg_link(pg, ttip=''):
        return {'tooltip': ttip,
                'href': f'http://tpc.org/tpc_documents_current_versions/pdf/tpc-di_v1.1.0.pdf#page={pg}',
                'target': "_blank"}

    with dot.subgraph(name='cluster_staging') as cs:
        cs.node('Date', 'Date', fillcolor='lightgray', style='filled', shape='note', **pg_link(29, ttip='Date.txt'))
        cs.node('Time', 'Time', fillcolor='lightgray', style='filled', shape='note', **pg_link(33, ttip='Time.txt'))
        cs.node('RawIndustry', 'Industry', fillcolor='lightgray', style='filled', shape='note',
                **pg_link(32, ttip='Industry.txt'))
        cs.node('RawStatusType', 'StatusType', fillcolor='lightgray', style='filled', shape='note',
                **pg_link(32, ttip='StatusType.txt'))
        cs.node('RawTaxRate', 'TaxRate', fillcolor='lightgray', style='filled', shape='note',
                **pg_link(33, ttip='TaxRate.txt'))
        cs.node('RawTradeType', 'TradeType', fillcolor='lightgray', style='filled', shape='note',
                **pg_link(34, ttip='TradeType.txt'))
        cs.node('Trade', 'Trade', fillcolor='lightgray', style='filled', shape='note', **pg_link(34, ttip='Trade.txt'))
        cs.node('TradeHistory', 'TradeHistory', fillcolor='lightgray', style='filled', shape='note',
                **pg_link(33, ttip='TradeHistory.txt'))
        cs.node('CashTransaction', 'CashTransaction', fillcolor='lightgray', style='filled', shape='note',
                **pg_link(21, ttip='CashTransaction.txt'))
        cs.node('HoldingHistory', 'HoldingHistory', fillcolor='lightgray', style='filled', shape='note',
                **pg_link(31, ttip='HoldingHistory.txt'))
        cs.node('DailyMarket', 'DailyMarket', fillcolor='lightgray', style='filled', shape='note',
                **pg_link(28, ttip='DailyMarket.txt'))
        cs.node('WatchHistory', 'WatchHistory', fillcolor='lightgray', style='filled', shape='note',
                **pg_link(35, ttip='WatchHistory.txt'))
        cs.node('HR', 'HR', fillcolor='lightgray', style='filled', shape='note', **pg_link(31, ttip='HR.csv'))
        cs.node('RawProspect', 'Prospect', fillcolor='lightgray', style='filled', shape='note',
                **pg_link(32, ttip='Prospect.csv'))
        cs.node('FINWIRE', 'FINWIRE', fillcolor='lightgray', style='filled', shape='note',
                **pg_link(29, ttip='FINWIRE'))
        cs.node('CustomerMgmt', 'CustomerMgmt', fillcolor='lightgray', style='filled', shape='note',
                **pg_link(23, ttip='CustomerMgmt.xml'))
        cs.body.append('label="Staging Area Data"')

    dot.edge('Date', 'Trade', style="invis")
    dot.edge('Date', 'TradeHistory', style="invis")
    dot.edge('Time', 'TradeHistory', style="invis")
    dot.edge('Time', 'CashTransaction', style="invis")
    dot.edge('RawIndustry', 'CashTransaction', style="invis")
    dot.edge('RawIndustry', 'HoldingHistory', style="invis")
    dot.edge('RawStatusType', 'HoldingHistory', style="invis")
    dot.edge('RawStatusType', 'DailyMarket', style="invis")
    dot.edge('RawTaxRate', 'DailyMarket', style="invis")
    dot.edge('RawTaxRate', 'WatchHistory', style="invis")
    dot.edge('RawTradeType', 'WatchHistory', style="invis")
    dot.edge('RawTradeType', 'HR', style="invis")

    dot.edge('Trade', 'RawProspect', style="invis")
    dot.edge('TradeHistory', 'RawProspect', style="invis")
    dot.edge('CashTransaction', 'RawProspect', style="invis")
    dot.edge('CashTransaction', 'FINWIRE', style="invis")
    dot.edge('HoldingHistory', 'FINWIRE', style="invis")
    dot.edge('DailyMarket', 'FINWIRE', style="invis")
    dot.edge('DailyMarket', 'CustomerMgmt', style="invis")
    dot.edge('WatchHistory', 'CustomerMgmt', style="invis")
    dot.edge('HR', 'CustomerMgmt', style="invis")

    with dot.subgraph(name='cluster_warehouse') as cw:
        with cw.subgraph(name='cluster_warehouse_first') as cwf:
            cwf.body.append('style="invis"')
            cwf.node('AuxFINWIRE', 'AuxFINWIRE', fillcolor='#FCFF99', style='filled', **pg_link(48, ttip='3.4.8'))
            cwf.node('Industry', 'Industry', fillcolor='#ECF1E0', style='filled', **pg_link(69, ttip='4.5.13'))
            cwf.node('StatusType', 'StatusType', fillcolor='#ECF1E0', style='filled', **pg_link(71, ttip='4.5.16'))
            cwf.node('TaxRate', 'TaxRate', fillcolor='#ECF1E0', style='filled', **pg_link(71, ttip='4.5.17'))
            cwf.node('AuxCustomerMgmt', 'AuxCustomerMgmt', fillcolor='#FCFF99', style='filled',
                     **pg_link(48, ttip='3.4.8'))
            cwf.node('AuxProspect', 'AuxProspect', fillcolor='#FCFF99', style='filled', **pg_link(48, ttip='3.4.8'))
            cwf.node('DimBroker', 'DimBroker', fillcolor='#FAEADC', style='filled', **pg_link(60, ttip='4.5.2'))
            cwf.node('TradeType', 'TradeType', fillcolor='#ECF1E0', style='filled', **pg_link(71, ttip='4.5.18'))
        cw.body.append('label="Data Warehouse Historical Loads"')
        cw.node('FactCashBalances', 'FactCashBalances', fillcolor='#CAD9EF', style='filled',
                **pg_link(66, ttip='4.5.9'))
        cw.node('FactHoldings', 'FactHoldings', fillcolor='#CAD9EF', style='filled', **pg_link(66, ttip='4.5.10'))
        cw.node('FactWatches', 'FactWatches', fillcolor='#CAD9EF', style='filled', **pg_link(71, ttip='4.5.16'))
        cw.node('FactMarketHistory', 'FactMarketHistory', fillcolor='#CAD9EF', style='filled',
                **pg_link(68, ttip='4.5.12'))
        cw.node('Prospect', 'Prospect', fillcolor='#CAD9EF', style='filled', **pg_link(69, ttip='4.5.15'))
        cw.node('DimTrade', 'DimTrade', fillcolor='#CAD9EF:#FAEADC', style='filled', gradientangle='180',
                **pg_link(65, ttip='4.5.8'))
        cw.node('DimCustomer', 'DimCustomer', fillcolor='#FAEADC', style='filled', **pg_link(61, ttip='4.5.4'))
        cw.node('DimAccount', 'DimAccount', fillcolor='#FAEADC', style='filled', **pg_link(58, ttip='4.5.1'))
        cw.node('DimSecurity', 'DimSecurity', fillcolor='#FAEADC', style='filled', **pg_link(64, ttip='4.5.6'))
        cw.node('DimCompany', 'DimCompany', fillcolor='#FAEADC', style='filled', **pg_link(60, ttip='4.5.3'))
        # cw.node('dim_date','DimDate',fillcolor = '#FAEADC:#ECF1E0', style='filled', gradientangle='0')
        # cw.node('dim_time','DimTime',fillcolor = '#FAEADC:#ECF1E0', style='filled', gradientangle='0')
        cw.node('Financial', 'Financial', fillcolor='#ECF1E0', style='filled', **pg_link(69, ttip='4.5.14'))
        # dot.node('di_messages','DImessages',fillcolor = '#E5E0EB', style='filled')
        # dot.node('audit','Audit',fillcolor = '#E5E0EB', style='filled')

    dot.edge('RawProspect', 'DimBroker', style="invis")
    dot.edge('RawProspect', 'TradeType', style="invis")
    dot.edge('RawProspect', 'AuxProspect', style="invis")
    dot.edge('FINWIRE', 'TaxRate', style="invis")
    dot.edge('FINWIRE', 'AuxCustomerMgmt', style="invis")
    dot.edge('CustomerMgmt', 'AuxFINWIRE', style="invis")
    dot.edge('CustomerMgmt', 'Industry', style="invis")
    dot.edge('CustomerMgmt', 'StatusType', style="invis")

    # dot.edge('CustomerMgmt', 'AuxCustomerMgmt')

    # dot.edge('FINWIRE', 'AuxFINWIRE')

    # dot.edge('RawProspect', 'AuxProspect')

    # dot.edge('AuxCustomerMgmt', 'DimAccount')
    dot.edge('DimCustomer', 'DimAccount')
    dot.edge('DimBroker', 'DimAccount')

    # dot.edge('HR', 'DimBroker')

    # dot.edge('AuxFINWIRE_CMP', 'DimCompany')
    dot.edge('AuxFINWIRE', 'DimCompany')
    dot.edge('StatusType', 'DimCompany')
    dot.edge('Industry', 'DimCompany')

    dot.edge('AuxCustomerMgmt', 'DimCustomer')
    dot.edge('AuxProspect', 'DimCustomer')
    dot.edge('TaxRate', 'DimCustomer')

    # dot.edge('Date','DimDate')

    # dot.edge('AuxFINWIRE_SEC', 'DimSecurity')
    # dot.edge('AuxFINWIRE', 'DimSecurity')
    # dot.edge('StatusType', 'DimSecurity')
    dot.edge('DimCompany', 'DimSecurity')

    # dot.edge('Time','DimTime')

    # dot.edge('Trade', 'DimTrade')
    # dot.edge('TradeHistory', 'DimTrade')
    # dot.edge('StatusType', 'DimTrade')
    dot.edge('TradeType', 'DimTrade')
    dot.edge('DimSecurity', 'DimTrade')
    dot.edge('DimAccount', 'DimTrade')

    # dot.edge('CashTransaction', 'FactCashBalances')
    dot.edge('DimAccount', 'FactCashBalances')
    # dot.edge('DimDate', 'FactCashBalances')

    # dot.edge('HoldingHistory', 'FactHoldings')
    dot.edge('DimTrade', 'FactHoldings')
    # dot.edge('DimDate', 'FactHoldings')

    # dot.edge('DailyMarket', 'FactMarketHistory')
    # dot.edge('AuxFINWIRE_FIN', 'FactMarketHistory')
    # dot.edge('AuxFINWIRE', 'FactMarketHistory')
    # dot.edge('DimCompany', 'FactMarketHistory')
    dot.edge('DimSecurity', 'FactMarketHistory')
    # dot.edge('DimDate', 'FactMarketHistory')

    # dot.edge('WatchHistory', 'FactWatches')
    dot.edge('DimCustomer', 'FactWatches')
    dot.edge('DimSecurity', 'FactWatches')
    # dot.edge('DimDate', 'FactWatches')

    # dot.edge('AuxFINWIRE_FIN', 'Financial')
    # dot.edge('AuxFINWIRE', 'Financial')
    dot.edge('DimCompany', 'Financial')

    # dot.edge('RawIndustry','Industry')

    # dot.edge('AuxProspect', 'Prospect')
    dot.edge('DimCustomer', 'Prospect')
    # dot.edge('DimDate', 'Prospect')

    # dot.edge('RawStatusType','StatusType')

    # dot.edge('RawTaxRate','TaxRate')

    # dot.edge('RawTradeType','TradeType')

    html = dot._repr_image_svg_xml()
    html = re.sub(r'<svg width=\"\d*pt\" height=\"\d*pt\"', '<svg width="1200pt"', html)

    return html
