"""
Incremental Loads

Graphic is intended to show the sequence of loads and source for Clause 4 Transformations

http://tpc.org/tpc_documents_current_versions/pdf/tpc-di_v1.1.0.pdf#page=52

"""

def get_incremental_html():
    import re
    from graphviz import Graph

    dot = Graph('tpcdi')
    dot.graph_attr['rankdir'] = 'LR'
    dot.attr('node', shape='rectangle')

    def pg_link(pg, ttip=''):
        return {'tooltip': ttip,
                'href': f'http://tpc.org/tpc_documents_current_versions/pdf/tpc-di_v1.1.0.pdf#page={pg}',
                'target': "_blank"}

    with dot.subgraph(name='cluster_staging') as cs:
        cs.node('Account', 'Account', fillcolor='lightgray', style='filled', shape='note',
                **pg_link(21, ttip='Account.txt'))
        cs.node('Customer', 'Customer', fillcolor='lightgray', style='filled', shape='note',
                **pg_link(22, ttip='Customer.txt'))
        cs.node('Trade', 'Trade', fillcolor='lightgray', style='filled', shape='note', **pg_link(34, ttip='Trade.txt'))
        cs.node('CashTransaction', 'CashTransaction', fillcolor='lightgray', style='filled', shape='note',
                **pg_link(21, ttip='CashTransaction.txt'))
        cs.node('HoldingHistory', 'HoldingHistory', fillcolor='lightgray', style='filled', shape='note',
                **pg_link(31, ttip='HoldingHistory.txt'))
        cs.node('DailyMarket', 'DailyMarket', fillcolor='lightgray', style='filled', shape='note',
                **pg_link(28, ttip='DailyMarket.txt'))
        cs.node('WatchHistory', 'WatchHistory', fillcolor='lightgray', style='filled', shape='note',
                **pg_link(35, ttip='WatchHistory.txt'))
        cs.node('RawProspect', 'Prospect', fillcolor='lightgray', style='filled', shape='note',
                **pg_link(32, ttip='Prospect.csv'))
        cs.body.append('label="Staging Area Data"')

    dot.edge('Trade', 'RawProspect', style="invis")
    dot.edge('CashTransaction', 'RawProspect', style="invis")
    dot.edge('HoldingHistory', 'RawProspect', style="invis")

    dot.edge('CashTransaction', 'Customer', style="invis")
    dot.edge('HoldingHistory', 'Customer', style="invis")
    dot.edge('DailyMarket', 'Customer', style="invis")

    dot.edge('HoldingHistory', 'Account', style="invis")
    dot.edge('DailyMarket', 'Account', style="invis")
    dot.edge('WatchHistory', 'Account', style="invis")

    with dot.subgraph(name='cluster_warehouse') as cw:
        with cw.subgraph(name='cluster_warehouse_first') as cwf:
            cwf.body.append('style="invis"')
            cwf.node('AuxProspect', 'AuxProspect', fillcolor='#FCFF99', style='filled', **pg_link(48, ttip='3.4.8'))
            cwf.node('FactMarketHistory', 'FactMarketHistory', fillcolor='#CAD9EF', style='filled',
                     **pg_link(75, ttip='4.5.10'))
        cw.body.append('label="Data Warehouse Historical Loads"')
        cw.node('FactCashBalances', 'FactCashBalances', fillcolor='#CAD9EF', style='filled',
                **pg_link(66, ttip='4.5.9'))
        cw.node('FactHoldings', 'FactHoldings', fillcolor='#CAD9EF', style='filled', **pg_link(66, ttip='4.5.10'))
        cw.node('FactWatches', 'FactWatches', fillcolor='#CAD9EF', style='filled', **pg_link(71, ttip='4.5.16'))
        cw.node('FactMarketHistory', 'FactMarketHistory', fillcolor='#CAD9EF', style='filled',
                **pg_link(68, ttip='4.5.12'))
        cw.node('Prospect', 'Prospect', fillcolor='#CAD9EF', style='filled', **pg_link(69, ttip='4.6.14'))
        cw.node('DimTrade', 'DimTrade', fillcolor='#CAD9EF:#FAEADC', style='filled', gradientangle='180',
                **pg_link(65, ttip='4.5.8'))
        cw.node('DimCustomer', 'DimCustomer', fillcolor='#FAEADC', style='filled', **pg_link(61, ttip='4.5.4'))
        cw.node('DimAccount', 'DimAccount', fillcolor='#FAEADC', style='filled', **pg_link(58, ttip='4.5.1'))

    dot.edge('Prospect', 'AuxProspect', style="invis")
    dot.edge('Customer', 'AuxProspect', style="invis")
    dot.edge('Customer', 'FactMarketHistory', style="invis")
    dot.edge('Account', 'FactMarketHistory', style="invis")

    dot.edge('DimCustomer', 'DimAccount')

    dot.edge('AuxProspect', 'DimCustomer')

    dot.edge('DimAccount', 'DimTrade')

    dot.edge('DimAccount', 'FactCashBalances')

    dot.edge('DimTrade', 'FactHoldings')

    dot.edge('DimCustomer', 'FactWatches')

    dot.edge('DimCustomer', 'Prospect')

    html = dot._repr_image_svg_xml()
    html = re.sub(r'<svg width=\"\d*pt\" height=\"\d*pt\"', '<svg width="1200pt"', html)

    return html
