"""
Historical Load Workflow

"""


def get_hl_workflow_html(wh_name):
    import re
    from graphviz import Digraph    


    dot = Digraph('tpcdi')
    dot.graph_attr['rankdir'] = 'LR'
    dot.attr('node', shape='rectangle')
    
    with dot.subgraph(name='cluster_external') as c:
        c.body.append('label="External Data Sources"')
        c.body.append('style="dashed"')
        c.body.append('color="blue"')
        c.node('oltp_db' ,'OLTP\nDB', fillcolor = 'lightgray', style='filled', shape='cylinder', tooltip="1.3.2", **{'href' :"http://tpc.org/tpc_documents_current_versions/pdf/tpc-di_v1.1.0.pdf#page=16"})
        c.node('hr_db' ,'HR\nDB', fillcolor = 'lightgray', style='filled', shape='cylinder')
        c.node('prospect_list' ,'Prospect\nList', fillcolor = 'lightgray', style='filled', shape='component')
        c.node('financial_newswire' ,'Financial\nNewswire', fillcolor = 'lightgray', style='filled', shape='cds')
        c.node('customer_mgmt_external' ,'Customer\nMgmt.', fillcolor = 'lightgray', style='filled', shape='cylinder')
    
    with dot.subgraph(name='cluster_staging') as c:
        c.node('account' ,'Account', fillcolor = 'lightgray', style='filled', shape='note', tooltip="Account.txt", **{'href' :'#table/hive_metastore/elh10bronze/account', 'target' :"_blank"})
        c.node('customer' ,'Customer', fillcolor = 'lightgray', style='filled', shape='note', tooltip="Customer.txt", **{'href' :'http://google.com'})
        c.node('trade' ,'Trade', fillcolor = 'lightgray', style='filled', shape='note', tooltip="Trade.txt", **{'href' :'http://google.com'})
        c.node('trade_hist' ,'TradeHistory', fillcolor = 'lightgray', style='filled', shape='note', tooltip="TradeHistory.txt", **{'href' :'http://google.com'})
        c.node('cash_transaction' ,'CashTransaction', fillcolor = 'lightgray', style='filled', shape='note', tooltip="CashTransaction.txt", **{'href' :'http://google.com'})
        c.node('holding_hist' ,'HoldingHistory', fillcolor = 'lightgray', style='filled', shape='note', tooltip="HoldingHistory.txt", **{'href' :'http://google.com'})
        c.node('daily_market' ,'DailyMarket', fillcolor = 'lightgray', style='filled', shape='note', tooltip="DailyMarket.txt", **{'href' :'http://google.com'})
        # NOTE: There is reference to a file WatchItem.txt in 1.3.2, it does not exist in the file generator and is likely a typo
        c.node('watch_hist' ,'WatchHistory', fillcolor = 'lightgray', style='filled', shape='note', tooltip="WatchHistory.txt", **{'href' :'http://google.com'})
        c.node('hr', 'HR', fillcolor = 'lightgray', style='filled', shape='note', tooltip="HR.csv", **{'href' :'http://google.com'})
        c.node('prospect', 'Prospect', fillcolor = 'lightgray', style='filled', shape='note', tooltip="Prospect.csv", **{'href' :'http://google.com'})
        c.node('finwire', 'FINWIRE', fillcolor = 'lightgray', style='filled', shape='note', tooltip="FINWIRE{yyyy}Q{q}", **{'href' :'http://google.com'})
        c.node('customer_mgmt', 'CustomerMgmt', fillcolor = 'lightgray', style='filled', shape='note', tooltip="CustomerMgmt.xml", **{'href' :'http://google.com'})
        c.node('date', 'Date', fillcolor = 'lightgray', style='filled', shape='note', tooltip="Date.txt", **{'href' :'http://google.com'})
        c.node('time', 'Time', fillcolor = 'lightgray', style='filled', shape='note', tooltip="Time.txt", **{'href' :'http://google.com'})
        c.node('stage_industry', 'Industry', fillcolor = 'lightgray', style='filled', shape='note', tooltip="Industry.txt", **{'href' :'http://google.com'})
        c.node('stage_status_type', 'StatusType', fillcolor = 'lightgray', style='filled', shape='note', tooltip="StatusType.txt", **{'href' :'http://google.com'})
        c.node('stage_tax_rate', 'TaxRate', fillcolor = 'lightgray', style='filled', shape='note', tooltip="TaxRate.txt", **{'href' :'http://google.com'})
        c.node('stage_trade_type', 'TradeType', fillcolor = 'lightgray', style='filled', shape='note', tooltip="TradeType.txt", **{'href' :'http://google.com'})
        c.body.append('label="Staging Area"')
    
    dot.edge('oltp_db' ,'account', tooltip="2.2.2.1", **{'href' :'http://tpc.org/tpc_documents_current_versions/pdf/tpc-di_v1.1.0.pdf#page=21', 'target' :"_blank"})
    dot.edge('oltp_db' ,'customer', tooltip="2.2.2.4", **{'href' :'http://tpc.org/tpc_documents_current_versions/pdf/tpc-di_v1.1.0.pdf#page=22', 'target' :"_blank"})
    dot.edge('oltp_db' ,'trade', tooltip="2.2.2.17", **{'href' :'http://tpc.org/tpc_documents_current_versions/pdf/tpc-di_v1.1.0.pdf#page=34', 'target' :"_blank"})
    dot.edge('oltp_db' ,'trade_hist', tooltip="2.2.2.16", **{'href' :'http://tpc.org/tpc_documents_current_versions/pdf/tpc-di_v1.1.0.pdf#page=33', 'target' :"_blank"})
    dot.edge('oltp_db' ,'cash_transaction', tooltip="2.2.2.3", **{'href' :'http://tpc.org/tpc_documents_current_versions/pdf/tpc-di_v1.1.0.pdf#page=21', 'target' :"_blank"})
    dot.edge('oltp_db' ,'holding_hist', tooltip="2.2.2.9", **{'href' :'http://tpc.org/tpc_documents_current_versions/pdf/tpc-di_v1.1.0.pdf#page=31', 'target' :"_blank"})
    dot.edge('oltp_db' ,'daily_market', tooltip="2.2.2.6", **{'href' :'http://tpc.org/tpc_documents_current_versions/pdf/tpc-di_v1.1.0.pdf#page=28', 'target' :"_blank"})
    dot.edge('oltp_db' ,'watch_hist', tooltip="2.2.2.19", **{'href' :'http://tpc.org/tpc_documents_current_versions/pdf/tpc-di_v1.1.0.pdf#page=35', 'target' :"_blank"})
    dot.edge('hr_db' ,'hr', tooltip="2.2.2.10", **{'href' :'http://tpc.org/tpc_documents_current_versions/pdf/tpc-di_v1.1.0.pdf#page=31', 'target' :"_blank"})
    dot.edge('prospect_list' ,'prospect', tooltip="2.2.2.12", **{'href' :'http://tpc.org/tpc_documents_current_versions/pdf/tpc-di_v1.1.0.pdf#page=32', 'target' :"_blank"})
    dot.edge('financial_newswire' ,'finwire', tooltip="2.2.2.8", **{'href' :'http://tpc.org/tpc_documents_current_versions/pdf/tpc-di_v1.1.0.pdf#page=29', 'target' :"_blank"})
    dot.edge('customer_mgmt_external' ,'customer_mgmt', tooltip="2.2.2.5", **{'href' :'http://tpc.org/tpc_documents_current_versions/pdf/tpc-di_v1.1.0.pdf#page=23', 'target' :"_blank"})
    dot.edge('date' ,'date', tooltip="2.2.2.7", **{'href' :'http://tpc.org/tpc_documents_current_versions/pdf/tpc-di_v1.1.0.pdf#page=29', 'target' :"_blank"})
    dot.edge('stage_industry' ,'stage_industry', tooltip="2.2.2.11", **{'href' :'http://tpc.org/tpc_documents_current_versions/pdf/tpc-di_v1.1.0.pdf#page=32', 'target' :"_blank"})
    dot.edge('stage_status_type' ,'stage_status_type', tooltip="2.2.2.13", **{'href' :'http://tpc.org/tpc_documents_current_versions/pdf/tpc-di_v1.1.0.pdf#page=32', 'target' :"_blank"})
    dot.edge('stage_tax_rate' ,'stage_tax_rate', tooltip="2.2.2.14", **{'href' :'http://tpc.org/tpc_documents_current_versions/pdf/tpc-di_v1.1.0.pdf#page=33', 'target' :"_blank"})
    dot.edge('time' ,'time', tooltip="2.2.2.15", **{'href' :'http://tpc.org/tpc_documents_current_versions/pdf/tpc-di_v1.1.0.pdf#page=33', 'target' :"_blank"})
    dot.edge('stage_trade_type' ,'stage_trade_type', tooltip="2.2.2.18", **{'href' :'http://tpc.org/tpc_documents_current_versions/pdf/tpc-di_v1.1.0.pdf#page=34', 'target' :"_blank"})
    
    
    with dot.subgraph(name='cluster_warehouse') as c:
        c.body.append('label="Warehouse Database"')
        with c.subgraph(name='cluster_warehouse_fact') as f:
            f.body.append('label="Fact Tables"')
            f.body.append('style="bold"')
            f.body.append('color="#CAD9EF"')
            f.node('FactCashBalances' ,'FactCashBalances' ,fillcolor = '#CAD9EF', style='filled', tooltip="3.2.9", **{'href' :'http://tpc.org/tpc_documents_current_versions/pdf/tpc-di_v1.1.0.pdf#page=43', 'target' :"_blank"})
            f.node('FactHoldings' ,'FactHoldings' ,fillcolor = '#CAD9EF', style='filled', tooltip="3.2.10", **{'href' :'http://tpc.org/tpc_documents_current_versions/pdf/tpc-di_v1.1.0.pdf#page=43', 'target' :"_blank"})
            f.node('FactWatches' ,'FactWatches' ,fillcolor = '#CAD9EF', style='filled', tooltip="3.2.12", **{'href' :'http://tpc.org/tpc_documents_current_versions/pdf/tpc-di_v1.1.0.pdf#page=44', 'target' :"_blank"})
            f.node('FactMarketHistory' ,'FactMarketHistory' ,fillcolor = '#CAD9EF', style='filled', tooltip="3.2.11", **{'href' :'http://tpc.org/tpc_documents_current_versions/pdf/tpc-di_v1.1.0.pdf#page=43', 'target' :"_blank"})
            f.node('Prospect' ,'Prospect' ,fillcolor = '#CAD9EF', style='filled', tooltip="3.2.15", **{'href' :'http://tpc.org/tpc_documents_current_versions/pdf/tpc-di_v1.1.0.pdf#page=45', 'target' :"_blank"})
        c.node('DimTrade' ,'DimTrade' ,fillcolor = '#CAD9EF:#FAEADC', style='filled', gradientangle='0', tooltip="3.2.7.1", **{'href' :'http://tpc.org/tpc_documents_current_versions/pdf/tpc-di_v1.1.0.pdf#page=41', 'target' :"_blank"})
        with c.subgraph(name='cluster_warehouse_dim') as d:
            d.body.append('label="Dimension Tables"')
            d.body.append('style="bold"')
            d.body.append('color="#FAEADC"')
            d.node('DimCustomer' ,'DimCustomer' ,fillcolor = '#FAEADC', style='filled', tooltip="3.2.4", **{'href' :'http://tpc.org/tpc_documents_current_versions/pdf/tpc-di_v1.1.0.pdf#page=39', 'target' :"_blank"})
            d.node('DimAccount' ,'DimAccount' ,fillcolor = '#FAEADC', style='filled', tooltip="3.2.1", **{'href' :'http://tpc.org/tpc_documents_current_versions/pdf/tpc-di_v1.1.0.pdf#page=38', 'target' :"_blank"})
            d.node('DimBroker' ,'DimBroker' ,fillcolor = '#FAEADC', style='filled', tooltip="3.2.2", **{'href' :'http://tpc.org/tpc_documents_current_versions/pdf/tpc-di_v1.1.0.pdf#page=38', 'target' :"_blank"})
            d.node('DimSecurity' ,'DimSecurity' ,fillcolor = '#FAEADC', style='filled', tooltip="3.2.6", **{'href' :'http://tpc.org/tpc_documents_current_versions/pdf/tpc-di_v1.1.0.pdf#page=41', 'target' :"_blank"})
            d.node('DimCompany' ,'DimCompany' ,fillcolor = '#FAEADC', style='filled', tooltip="3.2.3", **{'href' :'http://tpc.org/tpc_documents_current_versions/pdf/tpc-di_v1.1.0.pdf#page=39', 'target' :"_blank"})
        c.node('dim_date' ,'DimDate' ,fillcolor = '#FAEADC:#ECF1E0', style='filled', gradientangle='0', tooltip="3.2.5", **{'href' :'http://tpc.org/tpc_documents_current_versions/pdf/tpc-di_v1.1.0.pdf#page=40', 'target' :"_blank"})
        c.node('dim_time' ,'DimTime' ,fillcolor = '#FAEADC:#ECF1E0', style='filled', gradientangle='0', tooltip="3.2.7", **{'href' :'http://tpc.org/tpc_documents_current_versions/pdf/tpc-di_v1.1.0.pdf#page=41', 'target' :"_blank"})
        with c.subgraph(name='cluster_warehouse_ref') as r:
            r.body.append('label="Reference Tables"')
            r.body.append('style="bold"')
            r.body.append('color="#ECF1E0"')
            r.node('trade_type' ,'TradeType' ,fillcolor = '#ECF1E0', style='filled', tooltip="3.2.18", **{'href' :'http://tpc.org/tpc_documents_current_versions/pdf/tpc-di_v1.1.0.pdf#page=46', 'target' :"_blank"})
            r.node('status_type' ,'StatusType' ,fillcolor = '#ECF1E0', style='filled', tooltip="3.2.16", **{'href' :'http://tpc.org/tpc_documents_current_versions/pdf/tpc-di_v1.1.0.pdf#page=45', 'target' :"_blank"})
            r.node('tax_rate' ,'TaxRate' ,fillcolor = '#ECF1E0', style='filled', tooltip="3.2.17", **{'href' :'http://tpc.org/tpc_documents_current_versions/pdf/tpc-di_v1.1.0.pdf#page=45', 'target' :"_blank"})
            r.node('industry' ,'Industry' ,fillcolor = '#ECF1E0', style='filled', tooltip="3.2.13", **{'href' :'http://tpc.org/tpc_documents_current_versions/pdf/tpc-di_v1.1.0.pdf#page=44', 'target' :"_blank"})
            r.node('financial' ,'Financial' ,fillcolor = '#ECF1E0', style='filled', tooltip="3.2.14", **{'href' :'http://tpc.org/tpc_documents_current_versions/pdf/tpc-di_v1.1.0.pdf#page=44', 'target' :"_blank"})
        with c.subgraph(name='cluster_warehouse_di') as o:
            o.body.append('label="DI Operational Tables"')
            o.body.append('style="bold"')
            o.body.append('color="#E5E0EB"')
            o.node('DImessages' ,'DImessages' ,fillcolor = '#E5E0EB', style='filled', tooltip="3.2.8", **{'href' :'http://tpc.org/tpc_documents_current_versions/pdf/tpc-di_v1.1.0.pdf#page=42', 'target' :"_blank"})
            o.node('Audit' ,'Audit' ,fillcolor = '#E5E0EB', style='filled', tooltip="3.2.19", **{'href' :'http://tpc.org/tpc_documents_current_versions/pdf/tpc-di_v1.1.0.pdf#page=46', 'target' :"_blank"})
    
    
    dot.edge('date' ,'dim_date')
    dot.edge('time' ,'dim_time')
    dot.edge('stage_industry' ,'industry')
    dot.edge('stage_status_type' ,'status_type')
    dot.edge('stage_tax_rate' ,'tax_rate')
    dot.edge('stage_trade_type' ,'trade_type')
    
    # dot.format = 'png'
    # dot.render(filename='/dbfs/FileStore/tmp/cft')
    
    html = dot._repr_image_svg_xml()
    html = re.sub(r'<svg width=\"\d*pt\" height=\"\d*pt\"', '<svg height="500pt"', html)
    # html = re.sub(r'<svg width=\"\d*pt\" height=\"\d*pt\"', '<svg width="1200pt"', html)
    html = re.sub(r'font-size=\"14.00\">Fact Tables</text>', 'font-size=\"12.00\">Fact Tables</text>', html)
    html = re.sub(r'font-size=\"14.00\">Dimension Tables</text>', 'font-size=\"12.00\">Dimension Tables</text>', html)
    html = re.sub(r'font-size=\"14.00\">Reference Tables</text>', 'font-size=\"12.00\">Reference Tables</text>', html)
    html = re.sub(r'font-size=\"14.00\">DI Operational Tables</text>', 'font-size=\"12.00\">DI Operational Tables</text>', html)
    html = re.sub(r'stroke-width=\"2\"', 'stroke-width=\"4\"', html)
    
    return html