"""
AuxCustomerMgmt

This process is to load the CustomerMgmt data.
"""

from ..hl_transform import Hl_transform
from pyspark.sql import DataFrame
from pyspark.sql.functions import to_timestamp, col, to_date, when, lit, concat
from ...warehouse.tableDefTypes import *


class Hl_AuxCustomerMgmt(Hl_transform):

    source_names = {'staging': ['CustomerMgmt'],
                    'warehouse': []}

    # noinspection PyTypeChecker
    def _get_load_df(self) -> DataFrame:
        return self.source['CustomerMgmt'](1) \
            .select(col("_ActionType").alias('ActionType'),
                    to_timestamp(col("_ActionTS")).alias('ActionTS'),
                    col("Customer._C_ID").cast(IDENT_T).alias('C_ID'),
                    col("Customer._C_TAX_ID").alias('C_TAX_ID'),
                    col("Customer._C_GNDR").alias('C_GNDR'),
                    col("Customer._C_TIER").cast(ByteType()).alias('C_TIER'),
                    to_date(col("Customer._C_DOB")).alias('C_DOB'),
                    col("Customer.Name.C_L_NAME").alias('C_L_NAME'),
                    col("Customer.Name.C_F_NAME").alias('C_F_NAME'),
                    col("Customer.Name.C_M_NAME").alias('C_M_NAME'),
                    col("Customer.Address.C_ADLINE1").alias('C_ADLINE1'),
                    col("Customer.Address.C_ADLINE2").alias('C_ADLINE2'),
                    col("Customer.Address.C_ZIPCODE").alias('C_ZIPCODE'),
                    col("Customer.Address.C_CITY").alias('C_CITY'),
                    col("Customer.Address.C_STATE_PROV").alias('C_STATE_PROV'),
                    col("Customer.Address.C_CTRY").alias('C_CTRY'),
                    col("Customer.ContactInfo.C_PRIM_EMAIL").alias('C_PRIM_EMAIL'),
                    col("Customer.ContactInfo.C_ALT_EMAIL").alias('C_ALT_EMAIL'),
                    phoner('Customer.ContactInfo.C_PHONE_1').alias('C_PHONE_1'),
                    phoner('Customer.ContactInfo.C_PHONE_2').alias('C_PHONE_2'),
                    phoner('Customer.ContactInfo.C_PHONE_3').alias('C_PHONE_3'),
                    col("Customer.TaxInfo.C_LCL_TX_ID").alias('C_LCL_TX_ID'),
                    col("Customer.TaxInfo.C_NAT_TX_ID").alias('C_NAT_TX_ID'),
                    col("Customer.Account._CA_ID").cast(IDENT_T).alias('CA_ID'),
                    col("Customer.Account._CA_TAX_ST").cast(ByteType()).alias('CA_TAX_ST'),
                    col("Customer.Account.CA_B_ID").cast(IDENT_T).alias('CA_B_ID'),
                    col("Customer.Account.CA_NAME").cast(StringType()).alias('CA_NAME'))

def phoner(c_phone):
    ctry_code = col(c_phone + '.C_CTRY_CODE')
    area_code = col(c_phone + '.C_AREA_CODE')
    local = col(c_phone + '.C_LOCAL')
    ext = col(c_phone + '.C_EXT')
    ext = when(ext.isNull(), '').otherwise(ext)
    ph1 = concat(lit('+'), ctry_code, lit(' ('), area_code, lit(') '), local, lit(' '), ext)
    ph2 = concat(lit('('), area_code, lit(') '), local, lit(' '), ext)
    ph3 = concat(local, lit(' '), ext)
    return when(ph1.isNotNull(), ph1).otherwise(
            when(ph2.isNotNull(), ph2).otherwise(when(ph3.isNotNull(), ph3)))
