"""
AuxFINWIRE

This process is to load the FINWIRE data.
"""

from ..hl_transform import Hl_transform
from pyspark.sql import DataFrame
from pyspark.sql.functions import to_timestamp, col, lit, struct, when, to_date
from ...warehouse.tableDefTypes import *

class Hl_AuxFINWIRE(Hl_transform):

    source_names = {'staging': ['FINWIRE'],
                    'warehouse': []}

    # noinspection PyTypeChecker
    def _get_load_df(self) -> DataFrame:
        return self.source['FINWIRE'](1) \
            .select(to_timestamp(col('PTS')).alias('PTS'),
                    col('RecType'),
                    when(col('RecType') == lit('CMP'),
                         struct([col('CMP.CompanyName'),
                                 col('CMP.CIK').cast(DecimalType(11, 0)).alias('CIK'),
                                 col('CMP.Status'),
                                 col('CMP.IndustryID'),
                                 col('CMP.SPrating'),
                                 to_date(col('CMP.FoundingDate'), 'yyyyMMdd').alias('FoundingDate'),
                                 col('CMP.AddrLine1'),
                                 col('CMP.AddrLine2'),
                                 col('CMP.PostalCode'),
                                 col('CMP.City'),
                                 col('CMP.StateProvince'),
                                 col('CMP.Country'),
                                 col('CMP.CEOname'),
                                 col('CMP.Description')])).alias('CMP'),
                    when(col('RecType') == lit('SEC'),
                         struct([col('SEC.Symbol'),
                                 col('SEC.IssueType'),
                                 col('SEC.Status'),
                                 col('SEC.Name'),
                                 col('SEC.ExID'),
                                 col('SEC.ShOut').cast(IntegerType()).alias('ShOut'),
                                 to_date(col('SEC.FirstTradeDate'), 'yyyyMMdd').alias('FirstTradeDate'),
                                 to_date(col('SEC.FirstTradeExchg'), 'yyyyMMdd').alias('FirstTradeExchg'),
                                 col('SEC.Dividend').cast(DecimalType(10, 2)).alias('Dividend'),
                                 col('SEC.CIK').cast(DecimalType(11, 0)).alias('CIK'),
                                 col('SEC.CoName')])).alias('SEC'),
                    when(col('RecType') == lit('FIN'),
                         struct([col('FIN.Year').cast(ShortType()).alias('Year'),
                                 col('FIN.Quarter').cast(ByteType()).alias('Quarter'),
                                 to_date(col('FIN.QtrStartDate'), 'yyyyMMdd').alias('QtrStartDate'),
                                 to_date(col('FIN.PostingDate'), 'yyyyMMdd').alias('PostingDate'),
                                 col('FIN.Revenue').cast(DecimalType(14, 2)).alias('Revenue'),
                                 col('FIN.Earnings').cast(DecimalType(14, 2)).alias('Earnings'),
                                 col('FIN.EPS').cast(DecimalType(9, 2)).alias('EPS'),
                                 col('FIN.DilutedEPS').cast(DecimalType(9, 2)).alias('DilutedEPS'),
                                 col('FIN.Margin').cast(DecimalType(4, 2)).alias('Margin'),
                                 col('FIN.Inventory').cast(DecimalType(14, 2)).alias('Inventory'),
                                 col('FIN.Assets').cast(DecimalType(14, 2)).alias('Assets'),
                                 col('FIN.Liabilities').cast(DecimalType(14, 2)).alias('Liabilities'),
                                 col('FIN.ShOut').cast(IntegerType()).alias('ShOut'),
                                 col('FIN.DilutedShOut').cast(IntegerType()).alias('DilutedShOut'),
                                 col('FIN.CIK').cast(DecimalType(11, 0)).alias('CIK'),
                                 col('FIN.CoName')])).alias('FIN'))
