"""
AuxProspect

This process is to load the RawProspect data.
"""

from ..hl_transform import Hl_transform
from pyspark.sql import DataFrame
from pyspark.sql.functions import col, lit, when, concat_ws, date_format


class Hl_AuxProspect(Hl_transform):

    source_names = {'staging': ['RawProspect'],
                    'warehouse': []}

    # noinspection PyTypeChecker
    def _get_load_df(self) -> DataFrame:
        return self.source['RawProspect'](1) \
            .withColumn('SK_RecordDateID', date_format(lit(self.BatchDate), 'yyyyMMdd').cast('int')) \
            .select(col('AgencyID'),
                    col('SK_RecordDateID'),
                    col('SK_RecordDateID').alias('SK_UpdateDateID'),
                    lit(self.BatchID).alias('BatchID'),
                    col('LastName'),
                    col('FirstName'),
                    col('MiddleInitial'),
                    col('Gender'),
                    col('AddressLine1'),
                    col('AddressLine2'),
                    col('PostalCode'),
                    col('City'),
                    col('State'),
                    col('Country'),
                    col('Phone'),
                    col('Income'),
                    col('NumberCars'),
                    col('NumberChildren'),
                    col('MaritalStatus'),
                    col('Age'),
                    col('CreditRating'),
                    col('OwnOrRentFlag'),
                    col('Employer'),
                    col('NumberCreditCards'),
                    col('NetWorth'),
                    marketingnameplater())

def marketingnameplater():
    return concat_ws('+',
                     when((col('NetWorth') > lit(1000000)) | (col('Income') > lit(200000)), 'HighValue'),
                     when((col('NumberChildren') > lit(3)) | (col('NumberCreditCards') > lit(5)), 'Expenses'),
                     when(col('Age') > lit(45), "Boomer"),
                     when((col('Income') < lit(50000)) |
                          (col('CreditRating') < lit(600)) |
                          (col('NetWorth') < '10000'), "MoneyAlert"),
                     when((col('NumberCars') > lit(3)) | (col('NumberCreditCards') > lit(7)), "Spender"),
                     when((col('Age') < lit(25)) & (col('NetWorth') > lit(1000000)), "Inherited")) \
        .alias("MarketingNameplate")
