"""
Historic WorkFlow Part, DimAccount
**HISTORY TRACKING TABLE**


Transform Reference: 4.5.1
http://tpc.org/tpc_documents_current_versions/pdf/tpc-di_v1.1.0.pdf#page=58
"""

from ..hl_transform import Hl_transform
from pyspark.sql.functions import col, lit, row_number, when, collect_list, last, struct, explode, concat
from pyspark.sql.functions import to_date, lead, date_add
from pyspark.sql.window import Window as W
from pyspark.sql import DataFrame


class Hl_DimAccount(Hl_transform):

    source_names = {'staging': [],
                    'warehouse': ['AuxCustomerMgmt',
                                  'DimCustomer',
                                  'DimBroker']}

    def _get_load_df(self) -> DataFrame:
        w_sk_acct = W.partitionBy(lit(1)).orderBy([col('EffectiveDate'), col('AccountID')])
        w_acct = W.partitionBy(col('AccountID')).orderBy(col('Rec.EffectiveDate'))
        w_acct_prev = W.partitionBy(col('AccountID')) \
            .orderBy(col('Rec.EffectiveDate')) \
            .rowsBetween(W.unboundedPreceding, W.currentRow)

        def acct_prev(col_value, col_alias):
            return last(col_value, True).over(w_acct_prev).alias(col_alias)

        return self.source['AuxCustomerMgmt']().filter(~col('ActionType').isin(['UPDCUST', 'INACT'])) \
            .groupBy(col('C_ID').alias('CustomerID'), col('CA_ID').alias('AccountID')) \
            .agg(collect_list(struct(lit(None).alias('SK_CustomerID'),
                                     col('CA_B_ID'),
                                     when(col('ActionType') == lit('CLOSEACCT'), lit('INACTIVE')).otherwise(
                                         lit('ACTIVE')).alias('Status'),
                                     col('ActionTS').alias('EffectiveDate'),
                                     col('CA_NAME').alias('AccountDesc'),
                                     col('CA_TAX_ST').alias('TaxStatus'))).alias('AccountDetails')) \
            .join(self.source['DimCustomer']().groupBy(col('CustomerID'))
                  .agg(collect_list(struct(col('SK_CustomerID'),
                                           lit(None).alias('CA_B_ID'),
                                           when(col('Status') == lit('INACTIVE'), lit('INACTIVE')).alias('Status'),
                                           col('EffectiveDate').alias('EffectiveDate'),
                                           lit(None).alias('AccountDesc'),
                                           lit(None).alias('TaxStatus'))).alias('CustomerDetails')), ['CustomerID']) \
            .select(col('AccountID'), explode(concat(col('AccountDetails'), col('CustomerDetails'))).alias('Rec')) \
            .join(self.source['DimBroker'](), [col('Rec.CA_B_ID') == col('BrokerID'),
                                               col('Rec.EffectiveDate') >= col('EffectiveDate'),
                                               col('Rec.EffectiveDate') <= col('EndDate')], "left") \
            .withColumn('EffectiveDate', to_date(col('Rec.EffectiveDate'))) \
            .withColumn('next_ActionTS_minus_1', date_add(lead(col('EffectiveDate')).over(w_acct), -1)) \
            .select(col('AccountID'),
                    acct_prev(col('SK_BrokerID'), 'SK_BrokerID'),
                    acct_prev(col('Rec.SK_CustomerID'), 'SK_CustomerID'),
                    acct_prev(col('Rec.Status'), 'Status'),
                    acct_prev(col('Rec.AccountDesc'), 'AccountDesc'),
                    acct_prev(col('Rec.TaxStatus'), 'TaxStatus'),
                    when(col('next_ActionTS_minus_1').isNull(), lit(True)).otherwise(lit(False)).alias('isCurrent'),
                    lit(1).alias('BatchID'),
                    col('EffectiveDate'),
                    when(col('next_ActionTS_minus_1').isNull(), lit('9999-12-31'))
                    .otherwise(col('next_ActionTS_minus_1')).alias('EndDate')) \
            .filter(col('Status').isNotNull()) \
            .select(row_number().over(w_sk_acct).alias("SK_AccountID"),
                    col('*'))
