"""
Historic WorkFlow Part, DimSecurity
**HISTORY TRACKING TABLE**


Transform Reference: 4.5.6
http://tpc.org/tpc_documents_current_versions/pdf/tpc-di_v1.1.0.pdf#page=60
"""

from ..hl_transform import Hl_transform
from pyspark.sql.functions import col, lit, row_number, to_date, when, date_add, lead, substring
from pyspark.sql.window import Window as W
from pyspark.sql import DataFrame

class Hl_DimSecurity(Hl_transform):

    source_names = {'staging': [],
                    'warehouse': ['AuxFINWIRE_SEC',
                                  'StatusType',
                                  'DimCompany']}

    def _get_load_df(self) -> DataFrame:
        w_pts = W.partitionBy(col('Symbol')).orderBy(col('PTS'))
        w_row = W.partitionBy(lit(1)).orderBy(lit(1))
        return self.source['AuxFINWIRE_SEC']() \
            .join(self.source['DimCompany']().select([col('SK_CompanyID'),
                                                      col('CompanyID'),
                                                      col('Name').alias('sc_name'),
                                                      col('EffectiveDate'),
                                                      col('EndDate')]),
                  [(col('CoName') == col('sc_name')) | (col('CIK') == col('CompanyID')),
                   to_date(col('PTS')).between(col('EffectiveDate'), col('EndDate'))],
                  "left") \
            .join(self.source['StatusType'](), col('Status') == col('ST_ID'), "left") \
            .withColumn('lead_dte_minus_1', date_add(lead(col('PTS')).over(w_pts), -1)) \
            .select(row_number().over(w_row).alias("SK_SecurityID"),
                    col('Symbol').alias('Symbol'),
                    col('IssueType').alias('Issue'),
                    col('ST_NAME').alias('Status'),
                    col('Name').alias('Name'),
                    col('ExID').alias('ExchangeID'),
                    col('SK_CompanyID'),
                    col('ShOut').alias('SharesOutstanding'),
                    to_date(col('FirstTradeDate'), 'yyyyMMdd').alias('FirstTrade'),
                    to_date(col('FirstTradeExchg'), 'yyyyMMdd').alias('FirstTradeOnExchange'),
                    col('Dividend').alias('Dividend'),
                    when(col('lead_dte_minus_1').isNull(), lit(True)).otherwise(lit(False)).alias("IsCurrent"),
                    lit(1).alias("BatchID"),
                    substring(col('PTS').cast('string'), 1, 10).alias('EffectiveDate'),
                    when(col('lead_dte_minus_1').isNull(),
                         "9999-12-31").otherwise(col('lead_dte_minus_1')).alias('EndDate'))
