"""
Historic WorkFlow Part, FactHoldings


Transform Reference: 4.5.10
http://tpc.org/tpc_documents_current_versions/pdf/tpc-di_v1.1.0.pdf#page=66
"""

from ..hl_transform import Hl_transform
from pyspark.sql.functions import col, lit, to_date, date_format, sum
from pyspark.sql.window import Window as W
from pyspark.sql import DataFrame


class Hl_FactHoldings(Hl_transform):

    source_names = {'staging': ['HoldingHistory'],
                    'warehouse': ['DimTrade',
                                  'DimDate']}

    def _get_load_df(self) -> DataFrame:
        return self.source['HoldingHistory'](1) \
                 .join(self.source['DimTrade'](), [col('HH_T_ID') == col('TradeID')], 'left') \
                 .select(col('HH_H_T_ID').alias('TradeID'),
                         col('HH_T_ID').alias('CurrentTradeID'),
                         col('SK_CustomerID'),
                         col('SK_AccountID'),
                         col('SK_SecurityID'),
                         col('SK_CompanyID'),
                         col('SK_CloseDateID').alias('SK_DateId'),
                         col('SK_CloseTimeID').alias('SK_TimeID'),
                         col('TradePrice').alias('CurrentPrice'),
                         col('HH_AFTER_QTY').alias('CurrentHolding'),
                         lit(self.BatchID).alias('BatchID'))
