"""
Historic WorkFlow Part, FactWatches


Transform Reference: 4.5.12
http://tpc.org/tpc_documents_current_versions/pdf/tpc-di_v1.1.0.pdf#page=68
"""

from ..hl_transform import Hl_transform
from pyspark.sql import DataFrame
from pyspark.sql.functions import col, lit, date_format, to_date
from pyspark.sql import DataFrame


class Hl_FactWatches(Hl_transform):
    source_names = {'staging': ['WatchHistory'],
                    'warehouse': ['DimCustomer',
                                  'DimSecurity',
                                  'DimDate']}

    def _get_load_df(self) -> DataFrame:
        return self.source['WatchHistory'](1) \
            .withColumn('W_DTS', to_date(col('W_DTS'))) \
            .join(self.source['DimCustomer']()
                  .withColumnRenamed('EffectiveDate', 'dc_EffectiveDate')
                  .withColumnRenamed('EndDate', 'dc_EndDate'),
                  [col('W_C_ID') == col('CustomerID'),
                   col('W_DTS') >= col('dc_EffectiveDate'),
                   col('W_DTS') <= col('dc_EndDate')], 'left') \
            .join(self.source['DimSecurity']()
                  .withColumnRenamed('EffectiveDate', 'ds_EffectiveDate') \
                  .withColumnRenamed('EndDate', 'ds_EndDate'),
                  [col('W_S_SYMB') == col('Symbol'),
                   col('W_DTS') >= col('ds_EffectiveDate'),
                   col('W_DTS') <= col('ds_EndDate')], 'left') \
            .select(col('SK_CustomerID'),
                    col('SK_SecurityID'),
                    date_format(col('W_DTS'), 'yyyyMMdd').alias('SK_DateID_DatePlaced'),
                    lit(None).alias('SK_DateID_RateRemoved'),
                    lit(self.BatchID).alias('BatchID'))
