"""
Historic WorkFlow Part, Financial

Transform Reference: 4.5.14
http://tpc.org/tpc_documents_current_versions/pdf/tpc-di_v1.1.0.pdf#page=69
"""

from ..hl_transform import Hl_transform
from pyspark.sql.functions import col, to_date
from pyspark.sql import DataFrame


class Hl_Financial(Hl_transform):
    source_names = {'staging': [],
                    'warehouse': ['AuxFINWIRE_FIN',
                                  'DimCompany']}

    def _get_load_df(self) -> DataFrame:
        return self.source['AuxFINWIRE_FIN']() \
            .join(self.source['DimCompany'](),
                  [(col('CoName') == col('Name')) | (col('CIK') == col('CompanyID')),
                   to_date(col('PTS')).between(col('EffectiveDate'), col('EndDate'))]) \
            .select(col('SK_CompanyID'),
                    col('Year').alias('FI_YEAR'),
                    col('Quarter').alias('FI_QTR'),
                    to_date(col('QtrStartDate'), 'yyyyMMdd').alias('FI_QTR_START_DATE'),
                    col('Revenue').alias('FI_REVENUE'),
                    col('Earnings').alias('FI_NET_EARN'),
                    col('EPS').alias('FI_BASIC_EPS'),
                    col('DilutedEPS').alias('FI_DILUT_EPS'),
                    col('Margin').alias('FI_MARGIN'),
                    col('Inventory').alias('FI_INVENTORY'),
                    col('Assets').alias('FI_ASSETS'),
                    col('Liabilities').alias('FI_LIABILITY'),
                    col('ShOut').alias('FI_OUT_BASIC'),
                    col('DilutedShOut').alias('FI_OUT_DILUT'))
