"""
Historic WorkFlow Part, Prospect

Transform Reference: 4.5.15
http://tpc.org/tpc_documents_current_versions/pdf/tpc-di_v1.1.0.pdf#page=69
"""

from ..hl_transform import Hl_transform
from pyspark.sql.functions import col, lit, when, date_format
from delta import DeltaTable
from pyspark.sql import DataFrame

class Hl_Prospect(Hl_transform):
    source_names = {'staging': [],
                    'warehouse': ['AuxProspect',
                                  'DimCustomer',
                                  'DimDate']}

    def _get_load_df(self) -> DataFrame:
        return self.source['AuxProspect']() \
            .join(self.source['DimCustomer']().filter(col('isCurrent')).select(col('AgencyID').alias('dc_AgentID')),
                  col('AgencyID') == col('dc_AgentID'), 'left') \
            .withColumn('SK_RecordDateID', date_format(lit(self.BatchDate), 'yyyyMMdd').cast('int')) \
            .select(col('AgencyID'),
                    col('SK_RecordDateID'),
                    col('SK_RecordDateID').alias('SK_UpdateDateID'),
                    lit(self.BatchID).alias('BatchID'),
                    when(col('dc_AgentID').isNull(), lit(False)).otherwise(lit(True)).alias('isCustomer'),
                    col('LastName'),
                    col('FirstName'),
                    col('MiddleInitial'),
                    col('Gender'),
                    col('AddressLine1'),
                    col('AddressLine2'),
                    col('PostalCode'),
                    col('City'),
                    col('State'),
                    col('Country'),
                    col('Phone'),
                    col('Income'),
                    col('NumberCars'),
                    col('NumberChildren'),
                    col('MaritalStatus'),
                    col('Age'),
                    col('CreditRating'),
                    col('OwnOrRentFlag'),
                    col('Employer'),
                    col('NumberCreditCards'),
                    col('NetWorth'),
                    col('MarketingNameplate'))

    def _get_status_df(self):
        spark = self.load_df.sql_ctx.sparkSession
        num_output_rows = DeltaTable.forName(spark,
                                             self.target_name) \
            .history(1).select('operationMetrics.numOutputRows').collect()[0][0]
        status_data = [(self.CurrentTimestamp,
                        self.BatchID,
                        'Prospect',
                        'Inserted Rows',
                        'Status',
                        str(num_output_rows))]
        status_cols = ['MessageDateAndTime',
                       'BatchID',
                       'MessageSource',
                       'MessageText',
                       'MessageType',
                       'MessageData']
        return spark.createDataFrame(status_data, status_cols)
