"""
Class for consolidating all the Historic Load methods

"""

from .historical import TRANS_HL
from ..staging.staging import Staging
from ..warehouse.warehouse import Warehouse
from datetime import datetime as dt
from .gvHistorical import get_historical_html
from .gvDependency import get_trans_dependency_html
from .gvWorkFlow import get_hl_workflow_html
import threading as t


class HistoricalClass:

    def __init__(self,
                 stg: Staging,
                 wh: Warehouse):
        hl, sv = {}, {}
        with open('/dbfs' + stg.dir[5:] + '/Batch1/BatchDate.txt', "r") as file:
            sv['batch_date'] = file.readline()[:10]
        with open('/dbfs' + stg.dir[5:] + '/Batch1/Date.txt', "r") as file:
            sv['min_effective_date'] = file.readline().split('|')[1]
        sv['current_timestamp'] = str(dt.now())[:19]
        sv['batch_id'] = 1
        for hl_name, HL in TRANS_HL.items():
            hl[hl_name] = HL(stg, wh, **sv)
        self.HistoricLoad = hl
        self.wh_name = wh.name

    def run_purge(self):
        for HL in self.HistoricLoad.values():
            HL.run_purge()

    def create_views(self):
        # TODO: Create Views Output
        for HL in self.HistoricLoad.values():
            HL.create_views(short_name=False)

    @staticmethod
    def get_html():
        return get_historical_html()

    def get_trans_dependency_html(self):
        return get_trans_dependency_html(self.wh_name)

    def get_hl_workflow_html(self):
        return get_hl_workflow_html(self.wh_name)

    def run_loads(self):
        # Run all loads
        thl_dimdate = t.Thread(target=self.HistoricLoad['DimDate'].run_load)
        thl_dimtime = t.Thread(target=self.HistoricLoad['DimTime'].run_load)
        thl_auxfinwire = t.Thread(target=self.HistoricLoad['AuxFINWIRE'].run_load)
        thl_auxcustomermgmt = t.Thread(target=self.HistoricLoad['AuxCustomerMgmt'].run_load)
        thl_auxprospect = t.Thread(target=self.HistoricLoad['AuxProspect'].run_load)
        thl_dimbroker = t.Thread(target=self.HistoricLoad['DimBroker'].run_load)
        thl_industry = t.Thread(target=self.HistoricLoad['Industry'].run_load)
        thl_statustype = t.Thread(target=self.HistoricLoad['StatusType'].run_load)
        thl_taxrate = t.Thread(target=self.HistoricLoad['TaxRate'].run_load)
        thl_tradetype = t.Thread(target=self.HistoricLoad['TradeType'].run_load)
        thl_dimcustomer = t.Thread(target=self.HistoricLoad['DimCustomer'].run_load)
        thl_dimcompany = t.Thread(target=self.HistoricLoad['DimCompany'].run_load)
        thl_prospect = t.Thread(target=self.HistoricLoad['Prospect'].run_load)
        thl_financial = t.Thread(target=self.HistoricLoad['Financial'].run_load)
        thl_dimsecurity = t.Thread(target=self.HistoricLoad['DimSecurity'].run_load)
        thl_dimaccount = t.Thread(target=self.HistoricLoad['DimAccount'].run_load)
        thl_factmarkethistory = t.Thread(target=self.HistoricLoad['FactMarketHistory'].run_load)
        thl_factcashbalances = t.Thread(target=self.HistoricLoad['FactCashBalances'].run_load)
        thl_dimtrade = t.Thread(target=self.HistoricLoad['DimTrade'].run_load)
        thl_factwatches = t.Thread(target=self.HistoricLoad['FactWatches'].run_load)
        thl_factholdings = t.Thread(target=self.HistoricLoad['FactHoldings'].run_load)

        def grp_dimcustomer():
            thl_auxcustomermgmt.start()
            thl_auxprospect.start()
            thl_taxrate.start()
            thl_dimbroker.start()
            thl_auxcustomermgmt.join()
            thl_auxprospect.join()
            thl_taxrate.join()
            thl_dimcustomer.start()
            thl_dimcustomer.join()
            thl_prospect.start()
            thl_dimbroker.join()
            thl_dimaccount.start()

        tgrp_dimcustomer = t.Thread(target=grp_dimcustomer)

        def grp_dimsecurity():
            thl_auxfinwire.start()
            thl_industry.start()
            thl_statustype.start()
            thl_auxfinwire.join()
            thl_industry.join()
            thl_statustype.join()
            thl_dimcompany.start()
            thl_dimcompany.join()
            thl_financial.start()
            thl_dimsecurity.start()
            thl_dimsecurity.join()
            thl_factmarkethistory.start()

        tgrp_dimsecurity = t.Thread(target=grp_dimsecurity)

        tgrp_dimcustomer.start()
        tgrp_dimsecurity.start()
        thl_tradetype.start()
        thl_dimdate.start()
        thl_dimtime.start()

        thl_tradetype.join()
        tgrp_dimcustomer.join()
        tgrp_dimsecurity.join()
        thl_factwatches.start()

        thl_dimaccount.join()
        thl_dimtrade.start()
        thl_factcashbalances.start()

        thl_dimtrade.join()
        thl_factholdings.start()

        thl_dimdate.join()
        thl_dimtime.join()
        thl_prospect.join()
        thl_financial.join()
        thl_factmarkethistory.join()
        thl_factcashbalances.join()
        thl_factwatches.join()
        thl_factholdings.join()
