"""
AuxProspect

This process is to load the RawProspect data.
"""

from ..iu_transform import Iu_transform
from pyspark.sql import DataFrame
from pyspark.sql.functions import col, lit, when, concat_ws, date_format
from delta import DeltaTable

class Iu_AuxProspect(Iu_transform):

    source_names = {'staging': ['RawProspect'],
                    'warehouse': []}

    # noinspection PyTypeChecker
    def _get_update_df(self) -> DataFrame:
        return self.source['RawProspect'](self.BatchID) \
            .withColumn('SK_RecordDateID', date_format(lit(self.BatchDate), 'yyyyMMdd').cast('int')) \
            .select(col('AgencyID'),
                    col('SK_RecordDateID'),
                    col('SK_RecordDateID').alias('SK_UpdateDateID'),
                    lit(self.BatchID).alias('BatchID'),
                    col('LastName'),
                    col('FirstName'),
                    col('MiddleInitial'),
                    col('Gender'),
                    col('AddressLine1'),
                    col('AddressLine2'),
                    col('PostalCode'),
                    col('City'),
                    col('State'),
                    col('Country'),
                    col('Phone'),
                    col('Income'),
                    col('NumberCars'),
                    col('NumberChildren'),
                    col('MaritalStatus'),
                    col('Age'),
                    col('CreditRating'),
                    col('OwnOrRentFlag'),
                    col('Employer'),
                    col('NumberCreditCards'),
                    col('NetWorth'),
                    marketingnameplater())

    def run_merge(self):
        self.set_update_df()
        spark = self.update_df.sql_ctx.sparkSession
        DeltaTable.forName(spark, self.target_name).alias('tgt') \
            .merge(source=self.update_df.alias('mdf'),
                   condition=(col(f'tgt.`AgencyID`') == col(f'mdf.`AgencyID`'))) \
                .whenMatchedUpdateAll() \
                .whenNotMatchedInsertAll().execute()

def marketingnameplater():
    return concat_ws('+',
                     when((col('NetWorth') > lit(1000000)) | (col('Income') > lit(200000)), 'HighValue'),
                     when((col('NumberChildren') > lit(3)) | (col('NumberCreditCards') > lit(5)), 'Expenses'),
                     when(col('Age') > lit(45), "Boomer"),
                     when((col('Income') < lit(50000)) |
                          (col('CreditRating') < lit(600)) |
                          (col('NetWorth') < '10000'), "MoneyAlert"),
                     when((col('NumberCars') > lit(3)) | (col('NumberCreditCards') > lit(7)), "Spender"),
                     when((col('Age') < lit(25)) & (col('NetWorth') > lit(1000000)), "Inherited")) \
        .alias("MarketingNameplate")
