"""
Incremental WorkFlow Part, DimAccount
**HISTORY TRACKING TABLE**


Transform Reference: 4.6.1
http://tpc.org/tpc_documents_current_versions/pdf/tpc-di_v1.1.0.pdf#page=71
"""

from ..iu_transform import Iu_transform
from pyspark.sql.functions import col, lit, row_number, when, struct, upper, to_date, date_add, first, last
from pyspark.sql.window import Window as W
from ..colFunctions import phoner, marketingnameplater
from delta import DeltaTable
from pyspark.sql import DataFrame


class Iu_DimAccount(Iu_transform):

    hist_track_table = True

    source_names = {'staging': ['Account'],
                    'warehouse': ['DimBroker',
                                  'DimCustomer',
                                  'StatusType']}

    def _get_update_df(self) -> DataFrame:
        sk_account_id_last = int(self.target_tbl().agg({"SK_AccountID": "max"}).collect()[0][0])
        w_sk_acct = W.partitionBy(lit(1)).orderBy(lit(1))
        w_acct = W.partitionBy(col('CA_ID')).orderBy(col('CDC_DSN').desc())
        w_acct_prev = W.partitionBy(col('CA_ID')) \
            .orderBy(col('CDC_DSN').desc()) \
            .rowsBetween(W.currentRow, W.unboundedFollowing)

        def acct_prev(col_value, col_alias):
            return last(col_value, True).over(w_acct_prev).alias(col_alias)

        return self.source['Account'](self.BatchID) \
            .join(self.source['StatusType'](), col('CA_ST_ID') == col('ST_ID'), 'left') \
            .join(self.source['DimCustomer']().filter(col('isCurrent'))
                  .withColumnRenamed('Status', 'CustomerStatus'),
                  col('CA_C_ID') == col('CustomerID'), 'left') \
            .join(self.source['DimBroker']().filter(col('isCurrent')),
                  col('CA_B_ID') == col('BrokerID'), 'left') \
            .select(col('CA_ID').alias('AccountID'),
                    col('SK_BrokerID'),
                    col('SK_CustomerID'),
                    acct_prev(
                        when(col('CustomerStatus').isin(['INACTIVE', 'Inactive']), col('CustomerStatus')).otherwise(
                            col('ST_NAME')), 'Status'),
                    acct_prev(col('CA_NAME'), 'AccountDesc'),
                    acct_prev(col('CA_TAX_ST'), 'TaxStatus'),
                    lit(True).alias('isCurrent'),
                    lit(self.BatchID).alias('BatchID'),
                    to_date(lit(self.BatchDate)).alias('EffectiveDate'),
                    lit('9999-12-31').alias('EndDate'),
                    col('CDC_FLAG'),
                    row_number().over(w_acct).alias('row_num')) \
            .filter(col('row_num') == lit(1)).drop('row_num') \
            .select((lit(sk_account_id_last) + row_number().over(w_sk_acct)).alias('SK_AccountID'), col('*'))
