"""
Incremental WorkFlow Part, FactCashBalances


Transform Reference: 4.6.8
http://tpc.org/tpc_documents_current_versions/pdf/tpc-di_v1.1.0.pdf#page=75
"""

from ..iu_transform import Iu_transform
from pyspark.sql.functions import col, lit, to_date, date_format, sum
from pyspark.sql.window import Window as W
from pyspark.sql import DataFrame


class Iu_FactCashBalances(Iu_transform):

    source_names = {'staging': ['CashTransaction'],
                    'warehouse': ['DimAccount',
                                  'DimDate']}

    def _get_update_df(self) -> DataFrame:
        w_acct_prev = W.partitionBy(col('CT_CA_ID')) \
            .orderBy(col('dts')) \
            .rowsBetween(W.unboundedPreceding, W.currentRow)

        return self.source['CashTransaction'](self.BatchID) \
            .withColumn('dts', to_date(col('CT_DTS'))) \
            .join(self.source['DimAccount'](),
                  [col('CT_CA_ID') == col('AccountID'),
                   col('dts') >= col('EffectiveDate'),
                   col('dts') <= col('EndDate')]) \
            .select(col('SK_CustomerID'),
                    col('SK_AccountID'),
                    date_format(col('CT_DTS'), 'yyyyMMdd').alias('SK_DateID'),
                    sum(col('CT_AMT')).over(w_acct_prev).alias('Cash'),
                    lit(self.BatchID).alias('BatchID'))
