"""
Class for consolidating all the Incremental Update methods

"""

from .incremental import TRANS_IU
from ..staging.staging import Staging
from ..warehouse.warehouse import Warehouse
from datetime import datetime as dt
from .gvIncremental import get_incremental_html
import threading as t

class IncrementalClass:

    def __init__(self,
                 stg: Staging,
                 wh: Warehouse,
                 batch_id: int):
        iu, sv = {}, {}
        with open('/dbfs' + stg.dir[5:] + '/Batch1/BatchDate.txt', "r") as file:
            sv['batch_date'] = file.readline()[:10]
        with open('/dbfs' + stg.dir[5:] + '/Batch1/Date.txt', "r") as file:
            sv['min_effective_date'] = file.readline().split('|')[1]
        sv['current_timestamp'] = str(dt.now())[:19]
        sv['batch_id'] = batch_id
        for iu_name, IU in TRANS_IU.items():
            iu[iu_name] = IU(stg, wh, **sv)
        self.IncrementalUpdate = iu
        self.wh_name = wh.name

    def run_purge(self):
        for IU in self.IncrementalUpdate.values():
            IU.run_purge()

    def run_updates(self):
        # Run all updates
        tiu_auxprospect = t.Thread(target=self.IncrementalUpdate['AuxProspect'].run_update)
        tiu_factmarkethistory = t.Thread(target=self.IncrementalUpdate['FactMarketHistory'].run_update)
        tiu_dimcustomer = t.Thread(target=self.IncrementalUpdate['DimCustomer'].run_update)
        tiu_dimaccount = t.Thread(target=self.IncrementalUpdate['DimAccount'].run_update)
        tiu_prospect = t.Thread(target=self.IncrementalUpdate['Prospect'].run_update)
        tiu_factwatches = t.Thread(target=self.IncrementalUpdate['FactWatches'].run_update)
        tiu_dimtrade = t.Thread(target=self.IncrementalUpdate['DimTrade'].run_update)
        tiu_factcashbalances = t.Thread(target=self.IncrementalUpdate['FactCashBalances'].run_update)
        tiu_factholdings = t.Thread(target=self.IncrementalUpdate['FactHoldings'].run_update)

        tiu_auxprospect.start()
        tiu_factmarkethistory.start()
        tiu_auxprospect.join()
        tiu_dimcustomer.start()
        tiu_dimcustomer.join()
        tiu_dimaccount.start()
        tiu_prospect.start()
        tiu_factwatches.start()
        tiu_dimaccount.join()
        tiu_dimtrade.start()
        tiu_factcashbalances.start()
        tiu_dimtrade.join()
        tiu_factholdings.start()
        tiu_factmarkethistory.join()
        tiu_prospect.join()
        tiu_factwatches.join()
        tiu_factcashbalances.join()
        tiu_factholdings.join()

    def create_views(self):
        # TODO: Create Views Output
        for IU in self.IncrementalUpdate.values():
            IU.create_views(short_name=False)

    @staticmethod
    def get_html():
        return get_incremental_html()
