"""
AuxCustomerMgmt - An auxiliary table for CustomerMgmt

While the inclusion of an auxiliary table for nested, mixed-update (Customer + Account) isn't required,
it is the most likely approach that would be used in an actual production environment. Thus,
we'll use that approach here as well.

TPC-DI Requirements: 2.2.2.5, 3.4.8
TPC-DI Ref: http://tpc.org/tpc_documents_current_versions/pdf/tpc-di_v1.1.0.pdf#page=23
TPC-DI Ref: http://tpc.org/tpc_documents_current_versions/pdf/tpc-di_v1.1.0.pdf#page=48
"""

from ..whTable import WhTable
from ..tableDefTypes import *

# noinspection SqlResolve
class AuxCustomerMgmt(WhTable):
    definition = [("ActionType", StringType(), False, "One of: NEW, ADDACCT, APDCUST, APDACCT, CLOSEACCT, INACT"),
                  ("ActionTS", DATETIME, False, "Date and time of the action"),
                  ("C_ID", IDENT_T, True, "Customer identifier"),
                  ("C_TAX_ID", StringType(), True, "Customer’s tax identifier"),
                  ("C_GNDR", StringType(), True, "Gender of the customer"),
                  ("C_TIER", NUM(1), True, "Customer tier"),
                  ("C_DOB", DATE, True, "Customer’s date of birth"),
                  ("C_L_NAME", StringType(), True, "Customer's last name"),
                  ("C_F_NAME", StringType(), True, "Customer's first name"),
                  ("C_M_NAME", StringType(), True, "Customer's middle initial"),
                  ("C_ADLINE1", StringType(), True, "Address Line 1"),
                  ("C_ADLINE2", StringType(), True, "Address Line 2"),
                  ("C_ZIPCODE", StringType(), True, "Zip or postal code"),
                  ("C_CITY", StringType(), True, "City"),
                  ("C_STATE_PROV", StringType(), True, "State or province"),
                  ("C_CTRY", StringType(), True, "Country"),
                  ("C_PRIM_EMAIL", StringType(), True, "Customers Primary e-mail Address"),
                  ("C_ALT_EMAIL", StringType(), True, "Customers Alternate e-mail Address"),
                  ("C_PHONE_1", StringType(), True, "Primary phone number"),
                  ("C_PHONE_2", StringType(), True, "Secondary phone number"),
                  ("C_PHONE_3", StringType(), True, "Tertiary phone number"),
                  ("C_LCL_TX_ID", StringType(), True, "Customer's local tax rate"),
                  ("C_NAT_TX_ID", StringType(), True, "Customer's national tax rate"),
                  ("CA_ID", IDENT_T, True, "Customer account identifier"),
                  ("CA_TAX_ST", ByteType(), True, "Tax status of this account"),
                  ("CA_B_ID", IDENT_T, True, "Identifier of the managing broker"),
                  ("CA_NAME", StringType(), True, "Name of customer account")]
