"""
AuxCustomerMgmt - An auxiliary table for CustomerMgmt

While the inclusion of an auxiliary table for nested, mixed-update (Customer + Account) isn't required,
it is the most likely approach that would be used in an actual production environment. Thus,
we'll use that approach here as well.

TPC-DI Requirements: 2.2.2.5, 3.4.8
TPC-DI Ref: http://tpc.org/tpc_documents_current_versions/pdf/tpc-di_v1.1.0.pdf#page=23
TPC-DI Ref: http://tpc.org/tpc_documents_current_versions/pdf/tpc-di_v1.1.0.pdf#page=48
"""

from ..whTable import WhTable
from ..tableDefTypes import *

# noinspection SqlResolve
class AuxProspect(WhTable):
    definition = [('AgencyID',           StringType(),  False, 'Unique identifier from agency'),
                  ('SK_RecordDateID',    SK_T,          False, 'Last date this prospect appeared in input'),
                  ('SK_UpdateDateID',    SK_T,          False, 'Latest change date for this prospect'),
                  ('BatchID',            IntegerType(), True,  'Batch ID when this record was last modified'),
                  ('LastName',           StringType(),  False, 'Last Name'),
                  ('FirstName',          StringType(),  False, 'First Name'),
                  ('MiddleInitial',      StringType(),  True,  'Middle Initial'),
                  ('Gender',             StringType(),  True,  'M / F / U'),
                  ('AddressLine1',       StringType(),  True,  'Postal Address'),
                  ('AddressLine2',       StringType(),  True,  'Postal Address'),
                  ('PostalCode',         StringType(),  True,  'Postal Code'),
                  ('City',               StringType(),  False, 'City'),
                  ('State',              StringType(),  False, 'State or Province'),
                  ('Country',            StringType(),  True,  'Postal Country'),
                  ('Phone',              StringType(),  True,  'Telephone Number'),
                  ('Income',             IntegerType(), True,  'Annual Income'),
                  ('NumberCars',         ByteType(),    True,  'Cars Owned'),
                  ('NumberChildren',     ByteType(),    True,  'Dependent children'),
                  ('MaritalStatus',      StringType(),  True,  'S / M / D / W / U'),
                  ('Age',                NUM(3),        True,  'Current age'),
                  ('CreditRating',       ShortType(),   True,  'Numeric Rating'),
                  ('OwnOrRentFlag',      StringType(),  True,  'O / R / U'),
                  ('Employer',           StringType(),  True,  'Name of employer'),
                  ('NumberCreditCards',  ByteType(),    True,  'Number Credit Cards'),
                  ('NetWorth',           NUM(12),       True,  'Estimated Net Worth'),
                  ('MarketingNameplate', StringType(),  True,  'For Marketing Purposes')]
