"""
Functions for data warehouse DImessages

TPC-DI Requirement: 3.2.8
TPC-DI Ref: http://tpc.org/tpc_documents_current_versions/pdf/tpc-di_v1.1.0.pdf#page=42

Important Notes from Requirements:
There are five types of messages defined in the benchmark:
x “Status” messages give information about the DI processing.
x “Alert” messages provide information that certain conditions were detected which may
  need attention, but do not warrant excluding the data from the data warehouse. For
  example, customer tiers have the value 1, 2 or 3. If a different value appeared in a
  customer record, the record would be fully processed and an alert message would be
  written.
x Phase Complete Records (“PCR”) are written at the end of each phase and are used to calculate the phase elapsed times.
x “Validation” messages are written by the Batch Validation query (see Clause 7.4)
x “Visibility_1” and “Visibility_2” messages are written by the Data Visibility query (see Clause 7.3)
"""

from ..whTable import WhTable
from ..tableDefTypes import *


class DImessages(WhTable):

    definition = [("MessageDateAndTime", DATETIME,  False, "DATETIME Not NULL Date and time of the message"),
                  ("BatchID",            NUM(5),    False, "Not Null Batch ID when this record was inserted"),
                  ("MessageSource",      CHAR(30),  True,  'Typically the name of the transform that logs the message'),
                  ("MessageText",        CHAR(50),  False, 'Description of why the message was logged'),
                  ("MessageType",        CHAR(12),  False, 'Status, Alert, Reject, PCR, Validation, Visibility_1, Visibility_2'),
                  ("MessageData",        CHAR(100), True,  'Varies with the reason for logging the message')]
