"""
Functions for DataWarehouse DimAccount Table

TPC-DI Requirement: 3.2.1
TPC-DI Ref: http://tpc.org/tpc_documents_current_versions/pdf/tpc-di_v1.1.0.pdf#page=38
"""

from ..whTable import WhTable
from ..tableDefTypes import *


class DimAccount(WhTable):

    definition = [("SK_AccountID",  SK_T,      False, "Surrogate key for AccountID"),
                  ("AccountID",     IDENT_T,   False, "Customer account identifier"),
                  ("SK_BrokerID",   SK_T,      False, "Surrogate key of managing broker"),
                  ("SK_CustomerID", SK_T,      False, "Surrogate key of customer"),
                  ("Status",        CHAR(10) , False, "Account status, active or closed"),
                  ("AccountDesc",   CHAR(50),  True,  "Name of customer account"),
                  ("TaxStatus",     NUM(1),    False, "0, 1 or 2 Tax status of this account"),
                  ("IsCurrent",     BOOLEAN,   False, "True if this is the current record"),
                  ("BatchID",       NUM(5),    False, "Batch ID when this record was inserted"),
                  ("EffectiveDate", DATE,      False, "Current Record start date."),
                  ("EndDate",       DATE,      False, "Current record end date. Unexpired record will be 9999-12-31.")]
