"""
Functions for data warehouse DimCompany

TPC-DI Requirement: 3.2.3
TPC-DI Ref: http://tpc.org/tpc_documents_current_versions/pdf/tpc-di_v1.1.0.pdf#page=39
"""

from ..whTable import WhTable
from ..tableDefTypes import *


class DimCompany(WhTable):

    definition = [("SK_CompanyID",  SK_T,      False, "Surrogate key for CompanyID"),
                  ("CompanyID",     IDENT_T,   False, "Company identifier (CIK number)"),
                  ("Status",        CHAR(10),  False, "Company status"),
                  ("Name",          CHAR(60),  False, "Company name"),
                  ("Industry",      CHAR(50),  False, "Company’s industry"),
                  ("SPrating",      CHAR(4),   True,  "Standard & Poor company’s rating"),
                  ("isLowGrade",    BOOLEAN,   True,  "True if this company is low grade"),
                  ("CEO",           CHAR(100), False, "CEO name"),
                  ("AddressLine1",  CHAR(80),  True,  "Address Line 1"),
                  ("AddressLine2",  CHAR(80),  True,  "Address Line 2"),
                  ("PostalCode",    CHAR(12),  False, "Zip or postal code"),
                  ("City",          CHAR(25),  False, "City"),
                  ("StateProv",     CHAR(20),  False, "State or Province"),
                  ("Country",       CHAR(24),  True,  "Country"),
                  ("Description",   CHAR(150), False, "Company description"),
                  ("FoundingDate",  DATE,      True,  "Date the company was founded"),
                  ("IsCurrent",     BOOLEAN,   False, "True if this is the current record"),
                  ("BatchID",       NUM(5),    False, "Batch ID when this record was inserted"),
                  ("EffectiveDate", DATE,      False, "Current Record start date."),
                  ("EndDate",       DATE,      False, "Current record end date. Unexpired record will be 9999-12-31.")]
