"""
Functions for data warehouse DimCustomer

TPC-DI Requirement: 3.2.4
TPC-DI Ref: http://tpc.org/tpc_documents_current_versions/pdf/tpc-di_v1.1.0.pdf#page=39
"""

from ..whTable import WhTable
from ..tableDefTypes import *


class DimCustomer(WhTable):

    definition = [("SK_CustomerID",       SK_T,      False, "Not NULL Surrogate key for CustomerID"),
                  ("CustomerID",          IDENT_T,   False, "Not NULL Customer identifier"),
                  ("TaxID",               CHAR(20),  False, "Customer’s tax identifier"),
                  ("Status",              CHAR(10),  False, "Customer status type"),
                  ("LastName",            CHAR(30),  False, "Customer's last name."),
                  ("FirstName",           CHAR(30),  False, "Customer's first name."),
                  ("MiddleInitial",       CHAR(1),   True,  "Customer's middle name initial"),
                  ("Gender",              CHAR(1),   True,  "Gender of the customer"),
                  ("Tier",                NUM(1),    True,  "Customer tier"),
                  ("DOB",                 DATE,      False, "Customer’s date of birth."),
                  ("AddressLine1",        CHAR(80),  False, "Not NULL Address Line 1"),
                  ("AddressLine2",        CHAR(80),  True,  "Address Line 2"),
                  ("PostalCode",          CHAR(12),  False, "Zip or Postal Code"),
                  ("City",                CHAR(25),  False, "City"),
                  ("StateProv",           CHAR(20),  False, "State or Province"),
                  ("Country",             CHAR(24),  True,  "Country"),
                  ("Phone1",              CHAR(30),  True,  "Phone number 1"),
                  ("Phone2",              CHAR(30),  True,  "Phone number 2"),
                  ("Phone3",              CHAR(30),  True,  "Phone number 3"),
                  ("Email1",              CHAR(50),  True,  "Email address 1"),
                  ("Email2",              CHAR(50),  True,  "Email address 2"),
                  ("NationalTaxRateDesc", CHAR(50),  True,  "National Tax rate description"),
                  ("NationalTaxRate",     NUM(6,5),  True,  "National Tax rate"),
                  ("LocalTaxRateDesc",    CHAR(50),  True,  "Local Tax rate description"),
                  ("LocalTaxRate",        NUM(6,5),  True,  "Local Tax rate"),
                  ("AgencyID",            CHAR(30),  True,  "Agency identifier"),
                  ("CreditRating",        NUM(5),    True,  "Credit rating"),
                  ("NetWorth",            SNUM(10),  True,  "Net worth"),
                  ("MarketingNameplate",  CHAR(100), True,  "Marketing nameplate"),
                  ("IsCurrent",           BOOLEAN,   False, "True if this is the current record"),
                  ("BatchID",             NUM(5),    False, "Batch ID when this record was inserted"),
                  ("EffectiveDate",       DATE,      False, "Current Record start date."),
                  ("EndDate",             DATE,      False, "Current record end date. Unexpired record will be 9999-12-31.")]
