"""
Functions for data warehouse DimDate

TPC-DI Requirement: 3.2.5
TPC-DI Ref: http://tpc.org/tpc_documents_current_versions/pdf/tpc-di_v1.1.0.pdf#page=40

NOTE: Current format is written for Databricks Runtime 9.1. On future releases we should make use of:
   - Generated Columns: https://docs.delta.io/latest/delta-batch.html#use-generated-columns 
   - Interval Types: https://spark.apache.org/docs/latest/sql-ref-datatypes.html#supported-data-types
"""

from ..whTable import WhTable
from ..tableDefTypes import *


class DimDate(WhTable):

    definition = [("SK_DateID",         SK_T,     False, "Surrogate key for the date"),
                  ("DateValue",         DATE,     False, "The date stored appropriately for doing comparisons in the Data Warehouse"),
                  ("DateDesc",          CHAR(20), False, 'The date in full written form, e.g. “July 7,2004”'),
                  ("CalendarYearID",    NUM(4),   False, 'Year number as a number'),
                  ("CalendarYearDesc",  CHAR(20), False, 'Year number as text'),
                  ("CalendarQtrID",     NUM(5),   False, 'Quarter as a number, e.g. 20042'),
                  ("CalendarQtrDesc",   CHAR(20), False, 'Quarter as text, e.g. “2004 Q2”'),
                  ("CalendarMonthID",   NUM(6),   False, 'Month as a number, e.g. 20047'),
                  ("CalendarMonthDesc", CHAR(20), False, 'Month as text, e.g. “2004 July”'),
                  ("CalendarWeekID",    NUM(6),   False, 'Week as a number, e.g. 200428'),
                  ("CalendarWeekDesc",  CHAR(20), False, 'Week as text, e.g. “2004-W28”'),
                  ("DayOfWeekNum",      NUM(1),   False, 'Day of week as a number, e.g. 3'),
                  ("DayOfWeekDesc",     CHAR(10), False, 'Day of week as text, e.g. “Wednesday”'),
                  ("FiscalYearID",      NUM(4),   False, 'Fiscal year as a number, e.g. 2005'),
                  ("FiscalYearDesc",    CHAR(20), False, 'Fiscal year as text, e.g. “2005”'),
                  ("FiscalQtrID",       NUM(5),   False, 'Fiscal quarter as a number, e.g. 20051'),
                  ("FiscalQtrDesc",     CHAR(20), False, 'Fiscal quarter as text, e.g. “2005 Q1”'),
                  ("HolidayFlag",       BOOLEAN,  True,  'Indicates holidays')]
