"""
Functions for data warehouse DimSecurity

TPC-DI Requirement: 3.2.6
TPC-DI Ref: http://tpc.org/tpc_documents_current_versions/pdf/tpc-di_v1.1.0.pdf#page=41
"""

from ..whTable import WhTable
from ..tableDefTypes import *


class DimSecurity(WhTable):

    definition =[("SK_SecurityID",        SK_T,       False, 'Surrogate key for Symbol'),
                 ("Symbol",               CHAR(15),   False, 'Identifies security on “ticker”'),
                 ("Issue",                CHAR(6),    False, 'Issue type'),
                 ("Status",               CHAR(10),   False, 'Status type'),
                 ("Name",                 CHAR(70),   False, 'Security name'),
                 ("ExchangeID",           CHAR(6),    False, 'Exchange the security is traded on'),
                 ("SK_CompanyID",         SK_T,       False, 'Company issuing security'),
                 ("SharesOutstanding",    S_COUNT_T,  False, 'Shares outstanding'),
                 ("FirstTrade",           DATE,       False, 'Date of first trade'),
                 ("FirstTradeOnExchange", DATE,       False, 'Date of first trade on this exchange'),
                 ("Dividend",             VALUE_T,    False, 'Annual dividend per share'),
                 ("IsCurrent",            BOOLEAN,    False, "True if this is the current record"),
                 ("BatchID",              NUM(5),     False, "Batch ID when this record was inserted"),
                 ("EffectiveDate",        DATE,       False, "Current Record start date."),
                 ("EndDate",              DATE,       False, "Current record end date. Unexpired record will be 9999-12-31.")]
