"""
Functions for data warehouse DimTime

TPC-DI Requirement: 3.2.7
TPC-DI Ref: http://tpc.org/tpc_documents_current_versions/pdf/tpc-di_v1.1.0.pdf#page=41
NOTE: We are using https://en.wikipedia.org/wiki/ISO_8601 time format
NOTE: Current format is written for Databricks Runtime 9.1. On future releases we should make use of:
   - Generated Columns: https://docs.delta.io/latest/delta-batch.html#use-generated-columns 
   - Interval Types: https://spark.apache.org/docs/latest/sql-ref-datatypes.html#supported-data-types
"""

from ..whTable import WhTable
from ..tableDefTypes import *


class DimTime(WhTable):

    definition =[("SK_TimeID",       SK_T,     False, 'Surrogate key for the time'),
                 ("TimeValue",       TIME,     False, 'The time stored appropriately for doing comparisons in the Data Warehouse, hh:mm:ss '),
                 ("HourID",          NUM(2),   False, 'Not NULL Hour number as a number, e.g. 01'),
                 ("HourDesc",        CHAR(20), False, 'Hour number as text, e.g. “01”'),
                 ("MinuteID",        NUM(2),   False, 'Minute as a number, e.g. 23'),
                 ("MinuteDesc",      CHAR(20), False, 'Minute as text, e.g. “01:23”'),
                 ("SecondID",        NUM(2),   False, 'Second as a number, e.g. 45'),
                 ("SecondDesc",      CHAR(20), False, 'Second as text, e.g. “01:23:45”'),
                 ("MarketHoursFlag", BOOLEAN,  True,  'Indicates a time during market hours'),
                 ("OfficeHoursFlag", BOOLEAN,  True,  'Indicates a time during office hours')]
