"""
Functions for data warehouse DimTrade

TPC-DI Requirement: 3.2.7.1
TPC-DI Ref: http://tpc.org/tpc_documents_current_versions/pdf/tpc-di_v1.1.0.pdf#page=41

Important Notes from Requirements:
Unlike other dimension tables in the Data Warehouse, DimTrade is not maintained as a
history-tracking dimension. There are two state changes of concern for a trade: When it was
initiated and when it was completed or cancelled. Therefore the record has date and time
fields for the starting and ending states.
Rationale: This design is friendlier for users querying DimTrade as a fact table, because there
won’t be multiple records to consider for the same trade.
"""

from ..whTable import WhTable
from ..tableDefTypes import *


class DimTrade(WhTable):

    definition =[("TradeID",         IDENT_T,   False, "Trade identifier"),
                 ("SK_BrokerID",     SK_T,      True,  "Surrogate key for BrokerID"),
                 ("SK_CreateDateID", SK_T,      False, "Surrogate key for date created"),
                 ("SK_CreateTimeID", SK_T,      False, "Surrogate key for time created"),
                 ("SK_CloseDateID",  SK_T,      True,  "Surrogate key for date closed"),
                 ("SK_CloseTimeID",  SK_T,      True,  "Surrogate key for time closed"),
                 ("Status",          CHAR(10),  False, "Trade status"),
                 ("Type",            CHAR(12),  False, "Trade type"),
                 ("CashFlag",        BOOLEAN,   False, "Is this trade a cash (1, True) or margin (0, False) trade?"),
                 ("SK_SecurityID",   SK_T,      False, "Surrogate key for SecurityID"),
                 ("SK_CompanyID",    SK_T,      False, "Surrogate key for CompanyID"),
                 ("Quantity",        NUM(6,0),  False, "Quantity of securities traded."),
                 ("BidPrice",        NUM(8,2),  False, "The requested unit price."),
                 ("SK_CustomerID",   SK_T,      False, "Surrogate key for CustomerID"),
                 ("SK_AccountID",    SK_T,      False, "Surrogate key for AccountID"),
                 ("ExecutedBy",      CHAR(64),  False, "Name of person executing the trade."),
                 ("TradePrice",      NUM(8,2),  True,  "Unit price at which the security was traded."),
                 ("Fee",             NUM(10,2), True,  "Fee charged for placing this trade request"),
                 ("Commission",      NUM(10,2), True,  "Commission earned on this trade"),
                 ("Tax",             NUM(10,2), True,  "Amount of tax due on this trade"),
                 ("BatchID",         NUM(5),    False, "Not Null Batch ID when this record was inserted")]
