"""
Functions for data warehouse FactHoldings

TPC-DI Requirement: 3.2.10
TPC-DI Ref: http://tpc.org/tpc_documents_current_versions/pdf/tpc-di_v1.1.0.pdf#page=43
"""

from ..whTable import WhTable
from ..tableDefTypes import *


class FactHoldings(WhTable):

    definition =[("TradeID",        IDENT_T,   False, "Key for Orignial Trade Indentifier"),
                 ("CurrentTradeID", IDENT_T,   False, "Key for the current trade"),
                 ("SK_CustomerID",  SK_T,      False, "Surrogate key for Customer Identifier"),
                 ("SK_AccountID",   SK_T,      False, "Surrogate key for Account Identifier"),
                 ("SK_SecurityID",  SK_T,      False, "Surrogate key for Security Identifier"),
                 ("SK_CompanyID",   SK_T,      False, "Surrogate key for Company Identifier"),
                 ("SK_DateID",      SK_T,      False, "Surrogate key for the date associated with the current trade"),
                 ("SK_TimeID",      SK_T,      False, "Surrogate key for the time associated with the current trade"),
                 ("CurrentPrice",   S_PRICE_T, False, " > 0 Unit price of this security for the current trade"),
                 ("CurrentHolding", SNUM(6),   False, "Not NULL Quantity of a security held after the current trade. The value can be a positive or negative integer"),
                 ("BatchID",        NUM(5),    False, "Batch ID when this record was inserted")]
