"""
Functions for data warehouse FactMarketHistory

TPC-DI Requirement: 3.2.11
TPC-DI Ref: http://tpc.org/tpc_documents_current_versions/pdf/tpc-di_v1.1.0.pdf#page=43
"""


from ..whTable import WhTable
from ..tableDefTypes import *


class FactMarketHistory(WhTable):

    definition = [("SK_SecurityID",           SK_T,      False, "Surrogate key for SecurityID"),
                  ("SK_CompanyID",            SK_T,      False, "Surrogate key for CompanyID"),
                  ("SK_DateID",               SK_T,      False, "Surrogate key for the date"),
                  ("PERatio",                 NUM(10,2), True,  "Price to earnings per share ratio"),
                  ("Yield",                   NUM(5,2),  False, "Dividend to price ratio, as a percentage"),
                  ("FiftyTwoWeekHigh",        NUM(8,2),  False, "Security highest price in last 52 weeks from this day"),
                  ("SK_FiftyTwoWeekHighDate", SK_T,      False, "Earliest date on which the 52 week high price was set"),
                  ("FiftyTwoWeekLow",         NUM(8,2),  False, "Security lowest price in last 52 weeks from this day"),
                  ("SK_FiftyTwoWeekLowDate",  SK_T,      False, "Earliest date on which the 52 week low price was set"),
                  ("ClosePrice",              NUM(8,2),  False, "Security closing price on this day"),
                  ("DayHigh",                 NUM(8,2),  False, "Highest price for the security on this day"),
                  ("DayLow",                  NUM(8,2),  False, "Lowest price for the security on this day"),
                  ("Volume",                  NUM(12),   False, "Trading volume of the security on this day"),
                  ("BatchID",                 NUM(5),    False, "Batch ID when this record was inserted")]
