"""
Functions for data warehouse Financial

TPC-DI Requirement: 3.2.14
TPC-DI Ref: http://tpc.org/tpc_documents_current_versions/pdf/tpc-di_v1.1.0.pdf#page=44
"""

from ..whTable import WhTable
from ..tableDefTypes import *


class Financial(WhTable):

    definition = [("SK_CompanyID",      IDENT_T,    False, "Company SK."),
                  ("FI_YEAR",           NUM(4),     False, "Year of the quarter end."),
                  ("FI_QTR",            NUM(1),     False, "Quarter number that the financial information is for: valid values 1, 2, 3, 4."),
                  ("FI_QTR_START_DATE", DATE,       False, "Start date of quarter."),
                  ("FI_REVENUE",        SNUM(15,2), False, "Reported revenue for the quarter."),
                  ("FI_NET_EARN",       SNUM(15,2), False, "Net earnings reported for the quarter."),
                  ("FI_BASIC_EPS",      SNUM(10,2), False, "Basic earnings per share for the quarter."),
                  ("FI_DILUT_EPS",      SNUM(10,2), False, "Diluted earnings per share for the quarter."),
                  ("FI_MARGIN",         SNUM(10,2), False, "Profit divided by revenues for the quarter."),
                  ("FI_INVENTORY",      SNUM(15,2), False, "Value of inventory on hand at the end of quarter."),
                  ("FI_ASSETS",         SNUM(15,2), False, "Value of total assets at the end of the quarter."),
                  ("FI_LIABILITY",      SNUM(15,2), False, "Value of total liabilities at the end of the quarter."),
                  ("FI_OUT_BASIC",      SNUM(12),   False, "Average number of shares outstanding (basic)."),
                  ("FI_OUT_DILUT",      SNUM(12),   False, "Average number of shares outstanding (diluted).")]