"""
Functions for data warehouse Prospect

TPC-DI Requirement: 3.2.15
TPC-DI Ref: http://tpc.org/tpc_documents_current_versions/pdf/tpc-di_v1.1.0.pdf#page=45
"""

from ..whTable import WhTable
from ..tableDefTypes import *


class Prospect(WhTable):

    definition = [("AgencyID",           CHAR(30),  False, "Unique identifier from agency"),
                  ("SK_RecordDateID",    SK_T,      False, "Last date this prospect appeared in input"),
                  ("SK_UpdateDateID",    SK_T,      False, "Latest change date for this prospect"),
                  ("BatchID",            NUM(5),    False, "Batch ID when this record was last modified"),
                  ("IsCustomer",         BOOLEAN,   False, "True if this person is also in DimCustomer, else False"),
                  ("LastName",           CHAR(30),  False, "Last name"),
                  ("FirstName",          CHAR(30),  False, "First name"),
                  ("MiddleInitial",      CHAR(1),   True,  "Middle initial"),
                  ("Gender",             CHAR(1),   True,  "M / F / U"),
                  ("AddressLine1",       CHAR(80),  True,  "Postal address"),
                  ("AddressLine2",       CHAR(80),  True,  "Postal address"),
                  ("PostalCode",         CHAR(12),  True,  "Postal code"),
                  ("City",               CHAR(25),  False, "City"),
                  ("State",              CHAR(20),  False, "State or province"),
                  ("Country",            CHAR(24),  True,  "Postal country"),
                  ("Phone",              CHAR(30),  True,  "Telephone number"),
                  ("Income",             NUM(9),    True,  "Annual income"),
                  ("NumberCars",         NUM(2),    True,  "Cars owned"),
                  ("NumberChildren",     NUM(2),    True,  "Dependent children"),
                  ("MaritalStatus",      CHAR(1),   True,  "S / M / D / W / U"),
                  ("Age",                NUM(3),    True,  "Current age"),
                  ("CreditRating",       NUM(4),    True,  "Numeric rating"),
                  ("OwnOrRentFlag",      CHAR(1),   True,  "O / R / U"),
                  ("Employer",           CHAR(30),  True,  "Name of employer"),
                  ("NumberCreditCards",  NUM(2),    True,  "Credit cards"),
                  ("NetWorth",           NUM(12),   True,  "Estimated total net worth"),
                  ("MarketingNameplate", CHAR(100), True,  "For marketing purposes")]

