"""
Warehouse contains all DataWarehouse requirements for Clause 3: Data Warehouse

While the requirements for the Data Warehouse are in Clause 3, the actual phase of execution in defined in Preparation
Phase, Warehouse Creation (1.2.2.1.2). All functions in  __init__.py are to simplify calls during this sub-phase.

http://tpc.org/tpc_documents_current_versions/pdf/tpc-di_v1.1.0.pdf#page=37

TODO: Lazy Load: https://stackoverflow.com/questions/17486104/lazy-loading-of-class-attributes

"""

from .gvWarehouse import get_wh_html
from .table import WH_TABLES
import threading
from pyspark.sql import SparkSession 

class Warehouse:

    def __init__(self, wh_name):
        spark = SparkSession.builder.getOrCreate()
        self.spark = spark
        self.name = wh_name
        self.Tables = {t.__name__: t(spark, wh_name) for t in WH_TABLES}

    def create(self):
        self.spark.sql(f'CREATE DATABASE IF NOT EXISTS {self.name}')

    def drop(self):
        self.spark.sql(f'DROP DATABASE IF EXISTS {self.name}')

    def get_tables(self):
        return {k: v.get_table()  for k, v in self.Tables.items()}

    def get_names(self):
        return {k: v.tbl  for k, v in self.Tables.items()}

    def create_tables(self):
        # for t in self.Tables.values():
        #     t.create_table()
        table_threader = [threading.Thread(target=tc.create_table) for tc in self.Tables.values()]
        for t in table_threader:
            t.start()
        for t in table_threader:
            t.join()

    def purge_tables(self):
        # for t in self.Tables.values():
        #     t.purge_table()
        table_threader = [threading.Thread(target=tc.purge_table) for tc in self.Tables.values()]
        for t in table_threader:
            t.start()
        for t in table_threader:
            t.join()

    def drop_tables(self):
        # for t in self.Tables.values():
        #     t.drop_table()
        table_threader = [threading.Thread(target=tc.drop_table) for tc in self.Tables.values()]
        for t in table_threader:
            t.start()
        for t in table_threader:
            t.join()

    def create_views(self):
        # for t in self.Tables.values():
        #     t.create_view()
        table_threader = [threading.Thread(target=tc.create_view) for tc in self.Tables.values()]
        for t in table_threader:
            t.start()
        for t in table_threader:
            t.join()

    def get_html(self):
        return get_wh_html(self.name)
