"""
Parent Class For whTable classes

"""

from delta import DeltaTable
from pyspark.sql import DataFrame

class WhTable:

    definition = [("Column Name", "DataType", "Nullable", "Comment")]

    def __init__(self, spark, wh_name):
        self.spark = spark
        self.wh_name = wh_name
        self.tbl_name = self.__class__.__name__
        self.name = f'{self.wh_name}.{self.tbl_name}'

    def get_table(self) -> DataFrame:
        # table_path = 'dbfs:/user/hive/warehouse/' + self.wh_name + '.db/' + self.tbl_name.lower()
        # return self.spark.read.format('delta').load(table_path)
        return self.spark.table(self.name)

    def create_table(self) -> None:
        dt = DeltaTable.createIfNotExists(self.spark).tableName(self.name)
        for c in self.definition:
            dt.addColumn(*c[:-1], comment=c[-1])
        dt.execute()

    def drop_table(self) -> None:
        self.spark.sql(f'DROP TABLE IF EXISTS {self.name} ')

    def create_view(self) -> None:
        self.get_table().createOrReplaceTempView(self.tbl_name)

    def purge_table(self) -> None:
        self.spark.sql(f'DELETE FROM {self.name} WHERE 1=1')
        DeltaTable.forName(self.spark, self.name).vacuum()
